-- CityBinder - Bind File Generator for City of Heroes and City of Villains
-- Copyright (C) 2005  Jeff Sheets

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


local cats = {}
local mods = {}
local profile = {}
profile.__index = profile

function cbMakeDirectory(dir)
	os.execute('mkdir "'..dir..'"')
end

function cbOpen(filename, mode)
	local f
	f = assert(io.open(filename,mode))
	return f
end

local resetstring

function cbAddReset(s)
	resetstring = s.."$$"..resetstring
end

function profile:write()
	cbMakeDirectory(self.base)
	self.resetfile = cbOpen(self.base .. "\\reset.txt","w")
	resetstring = "bind_load_file_silent "..self.base.."\\reset.txt"
	if self.resetfile == nil then iup.Message("Error", "Resetfile not created!") end
	for _,module in pairs(mods) do
		if module.bindisused(self) then
			iup.Message("Saving...","Creating " .. module.label)
			module.makebind(self)
		end
	end
	self.resetfile:write(self.ResetKey..' "'..resetstring..'"\n')
	self.resetfile:close()
	self.resetfile = nil
	iup.Message("Saving...","Done!\n\nNow log on to the character you made this for and type:\n\n/bindloadfilesilent"..self.base.."\\reset.txt\n\nMake sure you use the \\ Backslash key for the file location!")
end

function cbNewBind(str)
	str = string.upper(str)
	local mkey,shift,ctrl,alt
	if string.find(str,"LSHIFT") then shift = "LSHIFT" end
	str = string.gsub(str,"LSHIFT","")
	if string.find(str,"RSHIFT") then shift = "RSHIFT" end
	str = string.gsub(str,"RSHIFT","")
	if string.find(str,"SHIFT") then shift = "LSHIFT" end
	str = string.gsub(str,"SHIFT","")
	if string.find(str,"LCTRL") then ctrl = "LCTRL" end
	str = string.gsub(str,"LCTRL","")
	if string.find(str,"RCTRL") then ctrl = "RCTRL" end
	str = string.gsub(str,"RCTRL","")
	if string.find(str,"CTRL") then ctrl = "LCTRL" end
	str = string.gsub(str,"CTRL","")
	if string.find(str,"LALT") then alt = "LALT" end
	str = string.gsub(str,"LALT","")
	if string.find(str,"RALT") then alt = "RALT" end
	str = string.gsub(str,"RALT","")
	if string.find(str,"ALT") then alt = "LCTRL" end
	str = string.gsub(str,"ALT","")
	mkey = string.gsub(str,"%+","")
	local t={}
	t.mainkey = mkey
	t.shift = shift
	t.ctrl = ctrl
	t.alt = alt
	t.bind = t.shift
	if (not t.bind) and t.ctrl then
		t.bind = t.ctrl
	elseif t.bind and t.ctrl then
		t.bind = t.bind.."+"..t.ctrl
	end
	if (not t.bind) and t.alt then
		t.bind = t.alt
	elseif t.bind and t.alt then
		t.bind = t.bind.."+"..t.alt
	end
	if (not t.bind) and t.mainkey then
		t.bind = t.mainkey
	elseif t.bind and not (t.mainkey == "") then
		t.bind = t.bind.."+"..t.mainkey
	end
	if not t.bind then t.bind = "" end
	return t
end

function cbSetBind(bindkey,curbind)
	bindkey = string.upper(bindkey)
	bindkey = string.upper(bindkey)
	if bindkey=="LSHIFT" or bindkey=="RSHIFT" then
		if bindkey==curbind.shift then
			curbind.shift=nil
		else
			curbind.shift = bindkey
		end
	elseif bindkey=="LCTRL" or bindkey=="RCTRL" then
		if bindkey==curbind.ctrl then
			curbind.ctrl=nil
		else
			curbind.ctrl = bindkey
		end
	elseif bindkey=="LALT" or bindkey=="RALT" then
		if bindkey==curbind.alt then
			curbind.alt=nil
		else
			curbind.alt = bindkey
		end
	else
		if curbind.mainkey == bindkey then
			curbind.mainkey = ""
		else
			curbind.mainkey = bindkey
		end
	end
	curbind.bind = curbind.shift
	if (not curbind.bind) and curbind.ctrl then
		curbind.bind = curbind.ctrl
	elseif curbind.bind and curbind.ctrl then
		curbind.bind = curbind.bind.."+"..curbind.ctrl
	end
	if (not curbind.bind) and curbind.alt then
		curbind.bind = curbind.alt
	elseif curbind.bind and curbind.alt then
		curbind.bind = curbind.bind.."+"..curbind.alt
	end
	if (not curbind.bind) and curbind.mainkey then
		curbind.bind = curbind.mainkey
	elseif curbind.bind and curbind.mainkey then
		curbind.bind = curbind.bind.."+"..curbind.mainkey
	end
	if not curbind.bind then curbind.bind = "" end
	curbind.bind = string.gsub(curbind.bind,"%+$","")
	if curbind.bind == "" then curbind.bind = "UNBOUND" end
end

function cbSetDesc(profile,bindkey,desc,label,t,k)
	profile.binds = profile.binds or {}
	profile.binds_label = profile.binds_label or {}
	profile.binds_tk = profile.binds_tk or {}
	if type(desc) == "function" then
		profile.binds[bindkey] = desc()
	else
		profile.binds[bindkey] = desc
	end
	profile.binds_label[bindkey] = label
	profile.binds_tk[bindkey] = {t = t; k = k}
end

function cbGetDesc(profile,bindkey)
	if profile.binds then
		return profile.binds[bindkey] or "Unbound"
	else
		return "Unknown"
	end
end

function cbUnboundOrEqualTo(a,b,profile)
	profile.binds = profile.binds or {}
	if profile.binds[a] then
		return a == b
	else
		return true
	end
end

function cbGetBindKey(bkey,desc,profile,label,t,k)
	local curbind = cbNewBind(bkey)
	curbind = cbPopVKeyboard(curbind,profile) -- This shouldn't return until after a bindkey was chosen.
	if curbind then
		-- check to see if the new key is unbound or identical to bkey, if not, ask for confirmation
		if not cbUnboundOrEqualTo(curbind.bind,bkey,profile) then
			-- ask for confirm, if yes then
			if iup.Alarm("Overwrite "..cbGetDesc(profile,curbind.bind).."?","This key combo is used for a different bind.  Overwrite it?","No","Yes") == 2 then
				-- overwrite the original bind to no key, or UNBOUND
				profile.binds_tk[curbind.bind].t[profile.binds_tk[curbind.bind].k] = "UNBOUND"
				if profile.binds_label[curbind.bind] then
					profile.binds_label[curbind.bind].title = "UNBOUND"
				end
				-- if the original key has a visible label indicating it's status, reset it's title.
				cbSetDesc(profile,bkey,nil,nil,nil,nil)
				cbSetDesc(profile,curbind.bind,desc,label,t,k)
				return curbind.bind
			else
				return bkey
			end
		else
			cbSetDesc(profile,bkey,nil,nil,nil,nil)
			cbSetDesc(profile,curbind.bind,desc,label,t,k)
			return curbind.bind
		end
	else
		return bkey
	end
end

--local function dumptable(file,o,depth)
--	depth = depth or 1
--	if type(o) == "number" then
--		file:write(o)
--	elseif type(o) == "string" then
--		file:write(string.format("%q", o))
--	elseif type(o) == "boolean" then
--		if o then file:write("true") else file:write("nil") end
--	elseif type(o) == "table" then
--		file:write("{\n")
--		for k,v in pairs(o) do
--			for i=1,depth do file:write("  ") end
--			file:write("[")
--			dumptable(file,k,0)
--			file:write("] = ")
--			dumptable(file,v,depth+1)
--			file:write(",\n")
--		end
--		for i=2,depth do file:write("  ") end
--		file:write("}")
--	elseif type(o) == "userdata" then
--		file:write("nil") -- because we don't test type til here and we can't serialize userdata.
--	else
--		error("cannot serialize a " .. type(o))
--	end
--end

local function basicSer(o)
	if type(o) == "number" then
		return tostring(o)
	elseif type(o) == "boolean" then
		return "true"
	elseif type(o) == "string" then
		return string.format("%q",o)
	else
		return "nil"
	end
end

local function dumptable(file,n,o,nList)
	nList = nList or {}
	file:write(n.." = ")
	if type(o) == "number" or type(o) == "string" or type(o) == "boolean" then
		file:write(basicSer(o).."\n")
	elseif type(o) == "table" then
		if nList[o] then
			file:write(nList[o].."\n")
		else
			nList[o] = n
			file:write("{}\n")
			for k,v in pairs(o) do
				dumptable(file,string.format("%s[%s]",n,basicSer(k)),v,nList)
			end
		end
	elseif type(o) == "userdata" then
		file:write("nil\n")
	else
		error("cannot save a "..type(o))
	end
end

function profile:saveprofile()
	cbMakeDirectory(string.sub(self.profile,1,(string.find(self.profile,"\\[^\\]+$"))))
	local profilefile = cbOpen(self.profile,"w")
	--profilefile:write("loadup = ")
	--dumptable(profilefile,self)
	dumptable(profilefile,"loadup",self)
	profilefile:close()
end

local cbTTip = nil
function cbToolTip(tip)
	cbTTip = tip
end

function cbToggleText(label,togval,txtval,togcb,txtcb,w,h,w2,h2)
	w = w or 100
	h = h or 21
	w2 = w2 or 100
	h2 = h2 or 21
	local ttext = iup.text{value = txtval; rastersize = w2.."x"..h2, tip = cbTTip}
	ttext.action = txtcb
	if not togval then ttext.active = "NO" end

	local chkval
	if togval then chkval = "ON" else chkval = "OFF" end

	local ttoggle = iup.toggle{title = label, value = chkval;rastersize = w.."x"..h, tip = cbTTip}
	ttoggle.action = function(_,v) togcb(_,v) if v == 1 then ttext.active ="YES" else ttext.active="NO" end end
	cbTTip = nil
	return iup.hbox{ttoggle,ttext;alignment="ACENTER"}
end

function cbTextBox(label,val,callback,w,h)
	w = w or 100
	h = h or 21
	local ttext = iup.text{value = val; rastersize = w.."x"..h, tip = cbTTip}
	ttext.action = callback
	cbTTip = nil
	return iup.hbox{iup.label{title = label; rastersize = w.."x"},ttext;alignment="ACENTER"}
end

function cbBindBox(label,t,k,callback,desc,profile,w,h,w2,h2)
	val = t[k]
	w = w or 100
	h = h or 21
	w2 = w2 or 100
	h2 = h2 or 21
	desc = desc or label
	local ttext = iup.label{title = val; rastersize = (w-20).."x"}
	--ttext.action = callback
	local tbtn = iup.button{title="..."; rastersize = "20x"..h, tip = cbTTip}
	tbtn.action = function()
		ttext.title = cbGetBindKey(t[k],desc,profile,ttext,t,k)
		callback(ttext.title)
	end
	cbTTip = nil
	return iup.hbox{iup.label{title = label; rastersize = w2.."x"},ttext,tbtn;alignment="ACENTER"}
end

function cbListBox(label,list,numitems,val,callback,w,h,w2,h2)
	w = w or 100
	h = h or 21
	w2 = w2 or 100
	h2 = h2 or 21
	local ttable = {}
	for i = 1,table.getn(list) do ttable[i] = list[i] end
	ttable.dropdown = "YES"
	ttable.visible_items = numitems
	ttable.value = val
	ttable.rastersize = w.."x"..h
	ttable.tip = cbTTip
	local tlist = iup.list(ttable)
	tlist.action = callback
	cbTTip = nil
	return iup.hbox{iup.label{title = label; rastersize = w2.."x"},tlist;alignment="ACENTER"}
end

function cbButton(label,callback,w,h,add)
	w = w or 200
	h = h or 21
	local t = {title = label; rastersize = w.."x"..h, tip = cbTTip}
	if add then
		for k,v in pairs(add) do t[k] = v end
	end
	local tbtn = iup.button(t)
	tbtn.action = callback
	cbTTip = nil
	return tbtn
end

function cbCheckbox(label,val,callback,w,h)
	w = w or 200
	h = h or 21
	local chkval
	if val then chkval = "ON" else chkval = "OFF" end
	
	local tchkbox = iup.toggle{title = label, value = chkval;rastersize = w.."x"..h, tip = cbTTip}
	tchkbox.action = callback
	cbTTip = nil
	return tchkbox
end

function cbNewProfile(name,filename)
	local t
	if name == nil then
		dofile(filename)
		t = loadup
	else
		dofile("default.lua")
		t = loadup
	end
	setmetatable(t,profile)
	local dlg = {}
	
	cbToolTip("Name your Profile!  This has no effect ingame or out")
	local tnamehbox = cbTextBox("Profile Name",t.name,function(_,c,v) t.name = v return iup.DEFAULT end)
	table.insert(dlg,tnamehbox)
	
	cbToolTip("This is where your bindfiles will be stored on your computer")
	local tbasehbox = cbTextBox("Bind Directory",t.base,function(_,c,v) t.base = v return iup.DEFAULT end)
	table.insert(dlg,tbasehbox)
	
	cbToolTip("This is the filename of your profile, which saves all your settings so you can make changes later easily")
	local tprofilehbox = cbTextBox("Profile Location",t.profile,function(_,c,v) t.profile = v return iup.DEFAULT end)
	table.insert(dlg,tprofilehbox)
	
	cbToolTip("Select your Character's Archetype")
	local tathbox = cbListBox("Archetype",{"Blaster","Brute","Controller","Corruptor","Defender","Dominator",
		 "Mastermind","Peacebringer","Scrapper","Stalker","Tanker","Warshade"},12,t.atnumber,
		 function(_,str,i,v) if v == 1 then t.archetype = str t.atnumber = i end end)
	table.insert(dlg,tathbox)
	
	cbToolTip("This key is used by certain modules to reset binds")
	local tresethbox = cbBindBox("Binds Reset Key",t,"ResetKey",function(s) t.ResetKey = s return iup.DEFAULT end,"Binds Reset Key",t)
	table.insert(dlg,tresethbox)
	
	for cat in pairs(cats) do
	for _,module in pairs(cats[cat]) do
		--local modbtn = iup.button{title = module.btnlabel; rastersize = "200x24"}
		local modbtnfunc = module.bindsettings
		local modbtn = cbButton(module.btnlabel,function(_) modbtnfunc(t) end)
		table.insert(dlg,modbtn)
	end
	end
	
	cbToolTip("Click this to save your CityBinder profile for later use and modification")
	local savebutton = cbButton("Save Profile",function(_) t:saveprofile() end)
	table.insert(dlg,savebutton)
	
	cbToolTip("Click this to generate your profile's bindfiles")
	local writebutton = cbButton("Generate Bindfiles",function(_) t:write() end)
	table.insert(dlg,writebutton)
	
	profiledlg = iup.dialog{iup.vbox(dlg);title = "Profile"}
	profiledlg:showxy(10,106)
	return t
end

function cbAddModule(module,label,category)
	module.category = category
	module.label = label
	module.btnlabel = category .. " : " .. label
	if cats[category] == nil then
		cats[category] = {}
	end
	cats[category][label] = module
	mods[category .. ":" .. label] = module
end
