-- CityBinder - Bind File Generator for City of Heroes and City of Villains
-- Copyright (C) 2005  Jeff Sheets

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


local module = {}

local function addCBind(cbinds,n) -- this returns an IUP vbox/hbox to be inserted into the CBind Dialog box
	local cbind = cbinds[n]
	local bindtext = iup.label{title = ""; SIZE = "100X"}
	local function matrix_value(_,l,c)
		if l == 0 then -- return the titles of columns
			if c == 0 then return "" elseif c == 1 then return "Bindkey" else return "Cycle "..(c - 1) end
		elseif c > 0 then -- return the values of the bindkeys
			if cbind[l] == nil then return "" end
			if c == 1 then return cbind[l].bindkey or nil else return cbind[l][c-1] or nil end
		end
	end
	local function matrix_value_edit(_,l,c,newval)
		cbind[l] = cbind[l] or {}
		if newval == "" then newval = nil end
		if c == 1 then cbind[l].bindkey = newval else cbind[l][c-1] = newval end
		return iup.DEFAULT
	end
	local function matrix_entercell(_,l,c)
		if cbind[l] == nil then bindtext.title = "" else
			if c == 1 then
				bindtext.title = cbind[l].bindkey or ""
			else
				bindtext.title = cbind[l][c-1] or ""
			end
		end
		return iup.DEFAULT
	end
	local matrix = iup.matrix{numcol="50";numlin="50";numcol_visible="5";numlin_visible="10";
		height0=8;value_cb = matrix_value; value_edit_cb = matrix_value_edit; enteritem_cb = matrix_entercell}
	for i = 2,50 do matrix["alignment"..i] = "ALEFT" end
	local delbtn = cbButton("Delete this Bind",function()
		if iup.Alarm("Confirm Deletion","Are you sure you want to delete this bind?","Yes","No") == 1 then
			table.remove(cbinds,n)
			cbinds.curbind = cbinds.curbind - 1
			if cbinds.curbind == 0 then cbinds.curbind = 1 end
			cbinds.dlg:hide()
			cbinds.dlg:destroy()
			cbinds.dlg = nil
			module.createDialog(cbinds)
			cbinds.dlg:showxy(218,10)
		end end)
	return iup.frame{iup.vbox{bindtext,matrix,delbtn},cx = 0, cy = 65 * (n-1)}
end

local function newCBind() -- this returns the default empty Simple Bind table to be inserted into SBinds
	local t = {}
	return t
end

function module.createDialog(cbinds)
	local box = {}
	for i = 1,table.getn(cbinds) do
		table.insert(box,addCBind(cbinds,i))
	end
	cbinds.curbind = cbinds.curbind or 1
	local newbindbtn = cbButton("New Complex Bind",
		function()
			table.insert(cbinds,newCBind())
			cbinds.curbind = table.getn(cbinds)
			cbinds.dlg:hide()
			cbinds.dlg:destroy()
			cbinds.dlg = nil
			module.createDialog(cbinds)
			cbinds.dlg:showxy(218,10)
		end,100)
	local sbEnablePrev = "NO"
	local sbEnableNext = "NO"
	if cbinds.curbind > 1 then sbEnablePrev = "YES" end
	cbinds.prevbind = cbButton("<<",function(self)
			cbinds.curbind = cbinds.curbind - 1
			cbinds.zbox.value = box[cbinds.curbind]
			cbinds.poslabel.title = cbinds.curbind.."/"..table.getn(cbinds)
			local sbEnablePrev = "NO"
			if cbinds.curbind > 1 then sbEnablePrev = "YES" end
			cbinds.prevbind.active=sbEnablePrev
			local sbEnableNext = "NO"
			if cbinds.curbind < table.getn(cbinds) then sbEnableNext = "YES" end
			cbinds.nextbind.active=sbEnableNext
		end,25,nil,{active=sbEnablePrev})
	if cbinds.curbind < table.getn(cbinds) then sbEnableNext = "YES" end
	cbinds.nextbind = cbButton(">>",function(self)
			cbinds.curbind = cbinds.curbind + 1
			cbinds.zbox.value = box[cbinds.curbind]
			cbinds.poslabel.title = cbinds.curbind.."/"..table.getn(cbinds)
			local sbEnablePrev = "NO"
			if cbinds.curbind > 1 then sbEnablePrev = "YES" end
			cbinds.prevbind.active=sbEnablePrev
			local sbEnableNext = "NO"
			if cbinds.curbind < table.getn(cbinds) then sbEnableNext = "YES" end
			cbinds.nextbind.active=sbEnableNext
		end,25,nil,{active=sbEnableNext})
	cbinds.poslabel = iup.label{title = cbinds.curbind.."/"..table.getn(cbinds);rastersize="50x";alignment="ACENTER"}
	box.value = box[cbinds.curbind]
	cbinds.zbox = iup.zbox(box)
	cbinds.dlg = iup.dialog{iup.vbox{cbinds.zbox,iup.hbox{cbinds.prevbind;newbindbtn;cbinds.poslabel;cbinds.nextbind;alignment="ACENTER"};alignment="ACENTER"};title = "General : Simple Binds"}
	cbinds.dlg.close_cb = function(self) cbinds.dlg = nil end
end

function module.bindsettings(profile)
	local cbinds = profile.cbinds
	if cbinds == nil then
		cbinds = {}
		profile.cbinds = cbinds
	end
	if cbinds.dlg then
		cbinds.dlg:show()
	else
		module.createDialog(cbinds)
		cbinds.dlg:showxy(218,10)
	end
end

local function maxKeys(cbind)
	local maxK = 0
	for n = 1,50 do
		if cbind[n] then
			if cbind[n].bindkey and not (cbind[n].bindkey == "") then
				maxK = n
			end
		end
	end
	return maxK
end

local function maxCycles(cbind,maxK)
	local maxC = 0
	for m = 1,maxK do
		for n = 2,50 do
			if cbind[m][n] and not (cbind[m][n] == "") then
				if n > maxC then maxC = n end
			end
		end
	end
	return maxC+1
end

local function writeBind(file,cbinds,key,cycle,bindset,maxC,profile)
	local nextCycle = cycle+1
	if nextCycle > maxC then nextCycle = 1 end
	--print(key.." "..cycle.." "..maxC.." "..nextCycle)
	file:write(cbinds[bindset][key].bindkey..' "')
	if cbinds[bindset][key][cycle] and not (cbinds[bindset][key][cycle] == "") then
		file:write(cbinds[bindset][key][cycle].."$$")
	end
	file:write("bind_load_file_silent "..profile.base.."\\cbinds\\"..bindset.."-"..nextCycle..'.txt"\n')
end

function module.makebind(profile)
	local resetfile = profile.resetfile
	local cbinds = profile.cbinds
	local cbindfile
	local maxK
	local maxC
	cbMakeDirectory(profile.base.."\\cbinds")
	for k = 1, table.getn(cbinds) do -- for each complex bind set
		maxK = maxKeys(cbinds[k])
		maxC = maxCycles(cbinds[k],maxK)
		--print("maxK = "..maxK..", maxC = "..maxC)
		for j = 1, maxC do -- for each cycle in this bindset, counting the first one twice
			--create a new bindfile if cycle is 2+
			if j > 1 then
				cbindfile = cbOpen(profile.base.."\\cbinds\\"..k.."-"..(j-1)..".txt","w")
				--print("created "..profile.base.."\\cbinds\\"..k.."-"..(j-1)..".txt")
			end
			for i = 1,maxK do -- for each key in the bindset
				if j == 1 then
					writeBind(resetfile,cbinds,i,j,k,maxC-1,profile)
				else
					writeBind(cbindfile,cbinds,i,j-1,k,maxC-1,profile)
				end
			end
			if j > 1 then
				cbindfile:close()
				--print("closed "..profile.base.."\\cbinds\\"..k.."-"..(j-1)..".txt")
			end
		end
	end
end

function module.bindisused(profile)
	if profile.cbinds == nil then return nil end
	return table.getn(profile.cbinds) > 0
end

cbAddModule(module,"Complex Binds","General")
