-- CityBinder - Bind File Generator for City of Heroes and City of Villains
-- Copyright (C) 2005  Jeff Sheets

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


local module = {}

function module.bindsettings(profile)
	local inspop = profile.inspop
	if inspop == nil then
		inspop = {}
		profile.inspop = inspop
		inspop.enable = nil
		inspop.acckey = "lshift+a"
		inspop.hpkey = "lshift+s"
		inspop.damkey = "lshift+d"
		inspop.endkey = "lshift+q"
		inspop.defkey = "lshift+w"
		inspop.bfkey = "lshift+e"
		inspop.reskey = "lshift+space"
	end
	if inspop.dialog then
		inspop.dialog:show()
	else
		cbToolTip("Check this to enable the Inspiration Popper Binds")
		local inspopenable = cbCheckbox("Enable Inspiration Popper",inspop.enable,
			function(_,v) if v == 1 then inspop.enable = true else inspop.enable = nil end end)
		cbToolTip("Choose the Key Combo that will activate an Accuracy Inspiration")
		local acchbox = cbBindBox("Accuracy Key",inspop,"acckey",function(s) inspop.acckey = s end,"Accuracy Key",profile)
		cbToolTip("Choose the Key Combo that will activate a Healing Inspiration")
		local hphbox = cbBindBox("Healing Key",inspop,"hpkey",function(s) inspop.hpkey = s end,"Healing Key",profile)
		cbToolTip("Choose the Key Combo that will activate a Damage Inspiration")
		local damhbox = cbBindBox("Damage Key",inspop,"damkey",function(s) inspop.damkey = s end,"Damage Key",profile)
		cbToolTip("Choose the Key Combo that will activate an Endurance Inspiration")
		local endhbox = cbBindBox("Endurance Key",inspop,"endkey",function(s) inspop.endkey = s end,"Endurance Key",profile)
		cbToolTip("Choose the Key Combo that will activate a Defense Inspiration")
		local defhbox = cbBindBox("Defense Key",inspop,"defkey",function(s) inspop.defkey = s end,"Defense Key",profile)
		cbToolTip("Choose the Key Combo that will activate a Breakfree Inspiration")
		local bfhbox = cbBindBox("Breakfree Key",inspop,"bfkey",function(s) inspop.bfkey = s end,"Breakfree Key",profile)
		cbToolTip("Choose the Key Combo that will activate a Resistance Inspiration")
		local reshbox = cbBindBox("Resistance Key",inspop,"reskey",function(s) inspop.reskey = s end,"Resistance Key",profile)
	
		local typdlg = iup.dialog{iup.vbox{inspopenable,acchbox,hphbox,damhbox,endhbox,defhbox,bfhbox,reshbox};title = "Gameplay : Inspiration Popper"}
		typdlg:showxy(218,10)
		inspop.dialog = typdlg
		typdlg.close_cb = function(self) inspop.dialog = nil end
	end
end

function module.makebind(profile)
	local resetfile = profile.resetfile
	local inspop = profile.inspop
	resetfile:write(inspop.acckey..' "tell $name, ACC$$inspexec_name Insight$$inspexec_name Keen Insight$$inspexec_name Uncanny Insight"\n')
	resetfile:write(inspop.hpkey..' "tell $name, HP$$inspexec_name Respite$$inspexec_name Dramatic Improvement$$inspexec_name Resurgance"\n')
	resetfile:write(inspop.damkey..' "tell $name, DAM$$inspexec_name Enrage$$inspexec_name Focused Rage$$inspexec_name Righteous Rage"\n')
	resetfile:write(inspop.endkey..' "tell $name, END$$inspexec_name Catch a Breath$$inspexec_name Take a Breather$$inspexec_name Second Wind"\n')
	resetfile:write(inspop.defkey..' "tell $name, DEF$$inspexec_name Luck$$inspexec_name Good Luck$$inspexec_name Phenomenal Luck"\n')
	resetfile:write(inspop.bfkey..' "tell $name, BF$$inspexec_name Break Free$$inspexec_name Emerge$$inspexec_name Escape"\n')
	resetfile:write(inspop.reskey..' "tell $name, RES$$inspexec_name Sturdy$$inspexec_name Rugged$$inspexec_name Robust"\n')
end

function module.bindisused(profile)
	if profile.inspop == nil then return nil end
	return profile.inspop.enable
end

cbAddModule(module,"Inspiration Popper","Gameplay")
