-- CityBinder - Bind File Generator for City of Heroes and City of Villains
-- Copyright (C) 2005  Jeff Sheets

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

-- creating a special version of the TextBox function, so as to make the chatty section easier to write.
function mmChatBoxes(label,list,methodval,txtval,methcb,txtcb)
	local h = 21
	local ttext = iup.text{value = txtval; rastersize = 375 .. "x"..h, tip = cbTTip}
	ttext.action = txtcb

	local ttable = {}
	for i = 1,table.getn(list) do ttable[i] = list[i] end
	ttable.dropdown = "YES"
	ttable.visible_items = table.getn(list)
	ttable.value = methodval
	ttable.rastersize = "75x"..h
	ttable.tip = "Choose the method used for Chatty feedback for this command."
	local tmethod = iup.list(ttable)
	tmethod.action = methcb
	cbTTip = nil
	return iup.hbox{iup.label{title=label; rastersize = "150x"};tmethod;ttext;alignment="ACENTER"}
end


local module = {}

function module.bindsettings(profile)
	local petselect = profile.petselect
	if petselect == nil then
		--iup.Message("Notice","Creating Default Pet Selection Bindings")
		petselect = {}
		profile.petselect = petselect
		petselect.sel0 = "F1"
		petselect.sel1 = "F2"
		petselect.sel2 = "F3"
		petselect.sel3 = "F4"
		petselect.sel4 = "F5"
		petselect.sel5 = "F6"
		petselect.enable = nil
	end
	-- load petselect bind dialog
	if petselect.dialog then
		petselect.dialog:show()
	else
		cbToolTip("Check this to Enable the Pet Selection Binds")
		local petselenable = cbCheckbox("Enable Pet Selection Binds",petselect.enable,
			function(_,v) if v == 1 then petselect.enable = true else petselect.enable = nil end end)
		cbToolTip("Choose the Key Combo that will select your First Pet")
		local petsel0hbox = cbBindBox("Select First Pet",petselect,"sel0",function(s) petselect.sel0 = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will select your Second Pet")
		local petsel1hbox = cbBindBox("Select Second Pet",petselect,"sel1",function(s) petselect.sel1 = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will select your Third Pet")
		local petsel2hbox = cbBindBox("Select Third Pet",petselect,"sel2",function(s) petselect.sel2 = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will select your Fourth Pet")
		local petsel3hbox = cbBindBox("Select Fourth Pet",petselect,"sel3",function(s) petselect.sel3 = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will select your Fifth Pet")
		local petsel4hbox = cbBindBox("Select Fifth Pet",petselect,"sel4",function(s) petselect.sel4 = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will select your Sixth Pet")
		local petsel5hbox = cbBindBox("Select Sixth Pet",petselect,"sel5",function(s) petselect.sel5 = s end,nil,profile)

		local petseldlg = iup.dialog{iup.vbox{petselenable,petsel0hbox,petsel1hbox,petsel2hbox,petsel3hbox,petsel4hbox,petsel5hbox};
			title = "Mastermind : Pet Selection Binds"}
		petseldlg:showxy(218,10)
		petselect.dialog = petseldlg
		petseldlg.close_cb = function(self) petselect.dialog = nil end
	end
end

function module.makebind(profile)
	local resetfile = profile.resetfile
	local petselect = profile.petselect
	resetfile:write(petselect.sel0 .. ' "petselect 0"\n')
	resetfile:write(petselect.sel1 .. ' "petselect 1"\n')
	resetfile:write(petselect.sel2 .. ' "petselect 2"\n')
	resetfile:write(petselect.sel3 .. ' "petselect 3"\n')
	resetfile:write(petselect.sel4 .. ' "petselect 4"\n')
	resetfile:write(petselect.sel5 .. ' "petselect 5"\n')
end

function module.bindisused(profile)
	if profile.petselect == nil then return nil end
	return profile.petselect.enable
end

cbAddModule(module,"Pet Select Bindings","Mastermind")

local module2 = {}

function module2.bindsettings(profile)
	local petaction = profile.petaction
	if petaction == nil then
		--iup.Message("Notice","Creating Default Pet Action Bindings")
		petaction = {}
		profile.petaction = petaction
		petaction.selall = "LALT+V"
		petaction.sayall = "Orders?"
		petaction.selmin = "LALT+Z"
		petaction.saymin = "Orders?"
		petaction.sellts = "LALT+X"
		petaction.saylts = "Orders?"
		petaction.selbos = "LALT+C"
		petaction.saybos = "Orders?"
		petaction.setagg = "LALT+A"
		petaction.sayagg = "Kill on Sight."
		petaction.setdef = "LALT+S"
		petaction.saydef = "Return Fire Only."
		petaction.setpas = "LALT+D"
		petaction.saypas = "At Ease."
		petaction.cmdatk = "LALT+Q"
		petaction.sayatk = "Open Fire!"
		petaction.cmdfol = "LALT+W"
		petaction.sayfol = "Falling In."
		petaction.cmdsty = "LALT+E"
		petaction.saysty = "Holding this Position."
		petaction.cmdgoto = "LALT+LBUTTON"
		petaction.saygo = "Moving to Checkpoint."
		petaction.enable = nil
		petaction.primnumber = 1
		petaction.primary = "Mercenaries"
	end
	petaction.sayallmethod = petaction.sayallmethod or petaction.selmethod or 3
	petaction.sayminmethod = petaction.sayminmethod or petaction.selmethod or 3
	petaction.sayltsmethod = petaction.sayltsmethod or petaction.selmethod or 3
	petaction.saybosmethod = petaction.saybosmethod or petaction.selmethod or 3
	petaction.sayaggmethod = petaction.sayaggmethod or petaction.cmdmethod or 3
	petaction.saydefmethod = petaction.saydefmethod or petaction.cmdmethod or 3
	petaction.saypasmethod = petaction.saypasmethod or petaction.cmdmethod or 3
	petaction.sayatkmethod = petaction.sayatkmethod or petaction.cmdmethod or 3
	petaction.sayfolmethod = petaction.sayfolmethod or petaction.cmdmethod or 3
	petaction.saystymethod = petaction.saystymethod or petaction.cmdmethod or 3
	petaction.saygomethod = petaction.saygomethod or petaction.cmdmethod or 3
	petaction.chattykey = petaction.chattykey or "LALT+M"
	-- load petaction bind dialog
	if petaction.dialog then
		petaction.dialog:show()
	else
		local credits = iup.hbox{iup.fill{};iup.vbox{
			iup.fill{size="5"},
			iup.label{title = "The Original Mastermind Control Binds"},
			iup.label{title = "were created in CoV Beta by Khaiba"},
			iup.label{title = "a.k.a. Sandolphan"},
			iup.fill{size="5"},
			alignment = "ACENTER"
		};iup.fill{};alignment = "ACENTER",rastersize="200x84"}

		cbToolTip("Check this to Enable the Pet Action binds")
		local petactenable = cbCheckbox("Enable Pet Action Binds",petaction.enable,
			function(_,v) if v == 1 then petaction.enable = true else petaction.enable = nil end end)
		cbToolTip("Choose your Mastermind's Primary Powerset")
		local mmprimhbox = cbListBox("MM Primary",{"Mercenaries","Necromancy","Ninjas","Robotics"},4,petaction.primnumber,
			function(_,str,i,v) if v == 1 then petaction.primnumber = i petaction.primary = str end end)
		cbToolTip("Choose the Key Combo that will enable commands on All your pets")
		local petselallhbox = cbBindBox("Select All",petaction,"selall",function(s) petaction.selall = s end,"Select All Pets",profile)
		cbToolTip("Choose the Key Combo that will enable commands on Your Tier 1 pets")
		local petselminhbox = cbBindBox("Select Minions",petaction,"selmin",function(s) petaction.selmin = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will enable commands on your Tier 2 pets")
		local petselltshbox = cbBindBox("Select Lieutenants",petaction,"sellts",function(s) petaction.sellts = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will enable commands on your Tier 3 pet")
		local petselboshbox = cbBindBox("Select Boss",petaction,"selbos",function(s) petaction.selbos = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will set your selected pets to Aggressive mode")
		local petsetagghbox = cbBindBox("Set Aggressive",petaction,"setagg",function(s) petaction.setagg = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will set your selected pets to Defensive mode")
		local petsetdefhbox = cbBindBox("Set Defense",petaction,"setdef",function(s) petaction.setdef = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will set your selected pets to Passive mode")
		local petsetpashbox = cbBindBox("Set Passive",petaction,"setpas",function(s) petaction.setpas = s end,nil,profile)
		cbToolTip("Choose the Key Combo that will command your selected pets to Attack your target")
		local petcmdatkhbox = cbBindBox("Attack",petaction,"cmdatk",function(s) petaction.cmdatk = s end,"Pet Order: Attack",profile)
		cbToolTip("Choose the Key Combo that will command your selected pets to Follow you")
		local petcmdfolhbox = cbBindBox("Follow",petaction,"cmdfol",function(s) petaction.cmdfol = s end,"Pet Order: Follow",profile)
		cbToolTip("Choose the Key Combo that will command your selected pets to Stay at their current location")
		local petcmdstyhbox = cbBindBox("Stay",petaction,"cmdsty",function(s) petaction.cmdsty = s end,"Pet Order: Stay",profile)
		cbToolTip("Choose the Key Combo that will command your selected pets to Go to a targetted location")
		local petcmdgotohbox = cbBindBox("Goto",petaction,"cmdgoto",function(s) petaction.cmdgoto = s end,"Pet Order: Goto",profile)

		cbToolTip("Choose the Key Combo that will switch from chatty mode to quiet mode")
		local petchattytgl = cbBindBox("Chat Mode Toggle",petaction,"chattykey",function(s) petaction.chattykey = s end,"Pet Action Bind Chatty Mode Toggle",profile)
		local chatlist = {"Local","Self-Tell","Petsay","None"}
		cbToolTip("Choose the Chat Response when selecting all your pets")
		local petsayallhbox = mmChatBoxes("Response to Select All",chatlist,petaction.sayallmethod,petaction.sayall,
			function(_,str,i,v) if v == 1 then petaction.sayallmethod = i end end,
			function(_,c,s) petaction.sayall = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when selecting your Tier 1 pets")
		local petsayminhbox = mmChatBoxes("Response to Select Minions",chatlist,petaction.sayminmethod,petaction.saymin,
			function(_,str,i,v) if v == 1 then petaction.sayminmethod = i end end,
			function(_,c,s) petaction.saymin = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when selecting your Tier 2 pets")
		local petsayltshbox = mmChatBoxes("Response to Select Lts.",chatlist,petaction.sayltsmethod,petaction.saylts,
			function(_,str,i,v) if v == 1 then petaction.sayltsmethod = i end end,
			function(_,c,s) petaction.saylts = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when selecting your Tier 3 pets")
		local petsayboshbox = mmChatBoxes("Response to Select Boss",chatlist,petaction.saybosmethod,petaction.saybos,
			function(_,str,i,v) if v == 1 then petaction.saybosmethod = i end end,
			function(_,c,s) petaction.saybos = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when setting your pets to Aggressive mode")
		local petsayagghbox = mmChatBoxes("Response to Set Aggressive",chatlist,petaction.sayaggmethod,petaction.sayagg,
			function(_,str,i,v) if v == 1 then petaction.sayaggmethod = i end end,
			function(_,c,s) petaction.sayagg = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when setting your pets to Defensive mode")
		local petsaydefhbox = mmChatBoxes("Response to Set Defensive",chatlist,petaction.saydefmethod,petaction.saydef,
			function(_,str,i,v) if v == 1 then petaction.saydefmethod = i end end,
			function(_,c,s) petaction.saydef = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when setting your pets to Passive mode")
		local petsaypashbox = mmChatBoxes("Response to Set Passive",chatlist,petaction.saypasmethod,petaction.saypas,
			function(_,str,i,v) if v == 1 then petaction.saypasmethod = i end end,
			function(_,c,s) petaction.saypas = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when commanding your pets to Attack")
		local petsayatkhbox = mmChatBoxes("Response to Attack",chatlist,petaction.sayatkmethod,petaction.sayatk,
			function(_,str,i,v) if v == 1 then petaction.sayatkmethod = i end end,
			function(_,c,s) petaction.sayatk = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when commanding your pets to Follow")
		local petsayfolhbox = mmChatBoxes("Response to Follow",chatlist,petaction.sayfolmethod,petaction.sayfol,
			function(_,str,i,v) if v == 1 then petaction.sayfolmethod = i end end,
			function(_,c,s) petaction.sayfol = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when commanding your pets to Stay")
		local petsaystyhbox = mmChatBoxes("Response to Stay",chatlist,petaction.saystymethod,petaction.saysty,
			function(_,str,i,v) if v == 1 then petaction.saystymethod = i end end,
			function(_,c,s) petaction.saysty = s return iup.DEFAULT end)
		cbToolTip("Choose the Chat Response when commanding your pets to Goto")
		local petsaygotohbox = mmChatBoxes("Response to Goto",chatlist,petaction.saygomethod,petaction.saygo,
			function(_,str,i,v) if v == 1 then petaction.saygomethod = i end end,
			function(_,c,s) petaction.saygo = s return iup.DEFAULT end)

		local petactdlg = iup.dialog{iup.vbox{credits,
			iup.hbox{iup.vbox{petactenable,mmprimhbox,petselallhbox,petselminhbox,petselltshbox,petselboshbox,
			petsetagghbox,petsetdefhbox,petsetpashbox,petcmdatkhbox,petcmdfolhbox,petcmdstyhbox,petcmdgotohbox},
			iup.vbox{petchattytgl,petsayallhbox,petsayminhbox,petsayltshbox,petsayboshbox,petsayagghbox,petsaydefhbox,petsaypashbox,petsayatkhbox,
			petsayfolhbox,petsaystyhbox,petsaygotohbox}}},
			title = "Mastermind : Pet Action Binds"}
		petactdlg:showxy(218,10)
		petaction.dialog = petactdlg
		petactdlg.close_cb = function(self) petaction.dialog = nil end
	end
end

function module2.makebind(profile)
	local resetfile = profile.resetfile
	local petaction = profile.petaction
	cbMakeDirectory(profile.base.."\\mmbinds")
	local allfile = cbOpen(profile.base .. "\\mmbinds\\all.txt","w")
	local minfile = cbOpen(profile.base .. "\\mmbinds\\tier1.txt","w")
	local ltsfile = cbOpen(profile.base .. "\\mmbinds\\tier2.txt","w")
	local bosfile = cbOpen(profile.base .. "\\mmbinds\\tier3.txt","w")
	local callfile = cbOpen(profile.base .. "\\mmbinds\\call.txt","w")
	local cminfile = cbOpen(profile.base .. "\\mmbinds\\ctier1.txt","w")
	local cltsfile = cbOpen(profile.base .. "\\mmbinds\\ctier2.txt","w")
	local cbosfile = cbOpen(profile.base .. "\\mmbinds\\ctier3.txt","w")
	local minpow
	local ltspow
	local bospow
	if petaction.primary == "Mercenaries" then
		minpow = "sol"
		ltspow = "spec"
		bospow = "com"
	elseif petaction.primary == "Ninjas" then
		minpow = "gen"
		ltspow = "joun"
		bospow = "oni"
	elseif petaction.primary == "Robotics" then
		minpow = "dron"
		ltspow = "prot"
		bospow = "ass"
	elseif petaction.primary == "Necromancy" then
		minpow = "zom"
		ltspow = "grav"
		bospow = "lich"
	end
	--"Local","Self-Tell","Petsay","None"
	local sayall
	local saymin
	local saylts
	local saybos
	local sayagg
	local saydef
	local saypas
	local sayatk
	local sayfol
	local saysty
	local saygo
	if petaction.sayallmethod < 4 then sayall = petaction.sayall .. "$$" else sayall = "" end
	if petaction.sayminmethod < 4 then saymin = petaction.saymin .. "$$" else saymin = "" end
	if petaction.sayltsmethod < 4 then saylts = petaction.saylts .. "$$" else saylts = "" end
	if petaction.saybosmethod < 4 then saybos = petaction.saybos .. "$$" else saybos = "" end
	if petaction.sayaggmethod < 4 then sayagg = petaction.sayagg .. "$$" else sayagg = "" end
	if petaction.saydefmethod < 4 then saydef = petaction.saydef .. "$$" else saydef = "" end
	if petaction.saypasmethod < 4 then saypas = petaction.saypas .. "$$" else saypas = "" end
	if petaction.sayatkmethod < 4 then sayatk = petaction.sayatk .. "$$" else sayatk = "" end
	if petaction.sayfolmethod < 4 then sayfol = petaction.sayfol .. "$$" else sayfol = "" end
	if petaction.saystymethod < 4 then saysty = petaction.saysty .. "$$" else saysty = "" end
	if petaction.saygomethod < 4 then saygo = petaction.saygo .. "$$" else saygo = "" end
	local saymethall = {"local ","tell, $name ","petsay_all ",""}
	local saymethmin = {"local ","tell, $name ","petsay_pow "..minpow.." ",""}
	local saymethlts = {"local ","tell, $name ","petsay_pow "..ltspow.." ",""}
	local saymethbos = {"local ","tell, $name ","petsay_pow "..bospow.." ",""}
	resetfile:write(petaction.selall .. ' "'..saymethall[petaction.sayallmethod]..sayall..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\call.txt"\n')
	resetfile:write(petaction.selmin .. ' "'..saymethmin[petaction.sayminmethod]..saymin..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier1.txt"\n')
	resetfile:write(petaction.sellts .. ' "'..saymethlts[petaction.sayltsmethod]..saylts..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier2.txt"\n')
	resetfile:write(petaction.selbos .. ' "'..saymethbos[petaction.saybosmethod]..saybos..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier3.txt"\n')
	resetfile:write(petaction.setagg .. ' "'..saymethall[petaction.sayaggmethod]..sayagg..'petcom_all Aggressive"\n')
	resetfile:write(petaction.setdef .. ' "'..saymethall[petaction.saydefmethod]..saydef..'petcom_all Defensive"\n')
	resetfile:write(petaction.setpas .. ' "'..saymethall[petaction.saypasmethod]..saypas..'petcom_all Passive"\n')
	resetfile:write(petaction.cmdatk .. ' "'..saymethall[petaction.sayatkmethod]..sayatk..'petcom_all Attack"\n')
	resetfile:write(petaction.cmdfol .. ' "'..saymethall[petaction.sayfolmethod]..sayfol..'petcom_all Follow"\n')
	resetfile:write(petaction.cmdsty .. ' "'..saymethall[petaction.saystymethod]..saysty..'petcom_all Stay"\n')
	resetfile:write(petaction.cmdgoto .. ' "'..saymethall[petaction.saygomethod]..saygo..'petcom_all Goto"\n')
	resetfile:write(petaction.chattykey..' "tell $name, Non-Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\all.txt"\n')
	allfile:write(petaction.selall .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\all.txt"\n')
	allfile:write(petaction.selmin .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier1.txt"\n')
	allfile:write(petaction.sellts .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier2.txt"\n')
	allfile:write(petaction.selbos .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier3.txt"\n')
	allfile:write(petaction.setagg .. ' "petcom_all Aggressive"\n')
	allfile:write(petaction.setdef .. ' "petcom_all Defensive"\n')
	allfile:write(petaction.setpas .. ' "petcom_all Passive"\n')
	allfile:write(petaction.cmdatk .. ' "petcom_all Attack"\n')
	allfile:write(petaction.cmdfol .. ' "petcom_all Follow"\n')
	allfile:write(petaction.cmdsty .. ' "petcom_all Stay"\n')
	allfile:write(petaction.cmdgoto .. ' "petcom_all Goto"\n')
	allfile:write(petaction.chattykey..' "tell $name, Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\call.txt"\n')
	minfile:write(petaction.selall .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\all.txt"\n')
	minfile:write(petaction.selmin .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier1.txt"\n')
	minfile:write(petaction.sellts .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier2.txt"\n')
	minfile:write(petaction.selbos .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier3.txt"\n')
	minfile:write(petaction.setagg .. ' "petcom_pow ' .. minpow .. ' Aggressive"\n')
	minfile:write(petaction.setdef .. ' "petcom_pow ' .. minpow .. ' Defensive"\n')
	minfile:write(petaction.setpas .. ' "petcom_pow ' .. minpow .. ' Passive"\n')
	minfile:write(petaction.cmdatk .. ' "petcom_pow ' .. minpow .. ' Attack"\n')
	minfile:write(petaction.cmdfol .. ' "petcom_pow ' .. minpow .. ' Follow"\n')
	minfile:write(petaction.cmdsty .. ' "petcom_pow ' .. minpow .. ' Stay"\n')
	minfile:write(petaction.cmdgoto .. ' "petcom_pow ' .. minpow .. ' Goto"\n')
	minfile:write(petaction.chattykey..' "tell $name, Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\ctier1.txt"\n')
	ltsfile:write(petaction.selall .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\all.txt"\n')
	ltsfile:write(petaction.selmin .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier1.txt"\n')
	ltsfile:write(petaction.sellts .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier2.txt"\n')
	ltsfile:write(petaction.selbos .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier3.txt"\n')
	ltsfile:write(petaction.setagg .. ' "petcom_pow ' .. ltspow .. ' Aggressive"\n')
	ltsfile:write(petaction.setdef .. ' "petcom_pow ' .. ltspow .. ' Defensive"\n')
	ltsfile:write(petaction.setpas .. ' "petcom_pow ' .. ltspow .. ' Passive"\n')
	ltsfile:write(petaction.cmdatk .. ' "petcom_pow ' .. ltspow .. ' Attack"\n')
	ltsfile:write(petaction.cmdfol .. ' "petcom_pow ' .. ltspow .. ' Follow"\n')
	ltsfile:write(petaction.cmdsty .. ' "petcom_pow ' .. ltspow .. ' Stay"\n')
	ltsfile:write(petaction.cmdgoto .. ' "petcom_pow ' .. ltspow .. ' Goto"\n')
	ltsfile:write(petaction.chattykey..' "tell $name, Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\ctier2.txt"\n')
	bosfile:write(petaction.selall .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\all.txt"\n')
	bosfile:write(petaction.selmin .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier1.txt"\n')
	bosfile:write(petaction.sellts .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier2.txt"\n')
	bosfile:write(petaction.selbos .. ' "bind_load_file_silent ' .. profile.base .. '\\mmbinds\\tier3.txt"\n')
	bosfile:write(petaction.setagg .. ' "petcom_pow ' .. bospow .. ' Aggressive"\n')
	bosfile:write(petaction.setdef .. ' "petcom_pow ' .. bospow .. ' Defensive"\n')
	bosfile:write(petaction.setpas .. ' "petcom_pow ' .. bospow .. ' Passive"\n')
	bosfile:write(petaction.cmdatk .. ' "petcom_pow ' .. bospow .. ' Attack"\n')
	bosfile:write(petaction.cmdfol .. ' "petcom_pow ' .. bospow .. ' Follow"\n')
	bosfile:write(petaction.cmdsty .. ' "petcom_pow ' .. bospow .. ' Stay"\n')
	bosfile:write(petaction.cmdgoto .. ' "petcom_pow ' .. bospow .. ' Goto"\n')
	bosfile:write(petaction.chattykey..' "tell $name, Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\ctier3.txt"\n')
	callfile:write(petaction.selall .. ' "'..saymethall[petaction.sayallmethod]..sayall..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\call.txt"\n')
	callfile:write(petaction.selmin .. ' "'..saymethmin[petaction.sayminmethod]..saymin..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier1.txt"\n')
	callfile:write(petaction.sellts .. ' "'..saymethlts[petaction.sayltsmethod]..saylts..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier2.txt"\n')
	callfile:write(petaction.selbos .. ' "'..saymethbos[petaction.saybosmethod]..saybos..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier3.txt"\n')
	callfile:write(petaction.setagg .. ' "'..saymethall[petaction.sayaggmethod]..sayagg..'petcom_all Aggressive"\n')
	callfile:write(petaction.setdef .. ' "'..saymethall[petaction.saydefmethod]..saydef..'petcom_all Defensive"\n')
	callfile:write(petaction.setpas .. ' "'..saymethall[petaction.saypasmethod]..saypas..'petcom_all Passive"\n')
	callfile:write(petaction.cmdatk .. ' "'..saymethall[petaction.sayatkmethod]..sayatk..'petcom_all Attack"\n')
	callfile:write(petaction.cmdfol .. ' "'..saymethall[petaction.sayfolmethod]..sayfol..'petcom_all Follow"\n')
	callfile:write(petaction.cmdsty .. ' "'..saymethall[petaction.saystymethod]..saysty..'petcom_all Stay"\n')
	callfile:write(petaction.cmdgoto .. ' "'..saymethall[petaction.saygomethod]..saygo..'petcom_all Goto"\n')
	callfile:write(petaction.chattykey..' "tell $name, Non-Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\all.txt"\n')
	cminfile:write(petaction.selall .. ' "'..saymethall[petaction.sayallmethod]..sayall..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\call.txt"\n')
	cminfile:write(petaction.selmin .. ' "'..saymethmin[petaction.sayminmethod]..saymin..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier1.txt"\n')
	cminfile:write(petaction.sellts .. ' "'..saymethlts[petaction.sayltsmethod]..saylts..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier2.txt"\n')
	cminfile:write(petaction.selbos .. ' "'..saymethbos[petaction.saybosmethod]..saybos..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier3.txt"\n')
	cminfile:write(petaction.setagg .. ' "'..saymethmin[petaction.sayaggmethod]..sayagg..'petcom_pow ' .. minpow .. ' Aggressive"\n')
	cminfile:write(petaction.setdef .. ' "'..saymethmin[petaction.saydefmethod]..saydef..'petcom_pow ' .. minpow .. ' Defensive"\n')
	cminfile:write(petaction.setpas .. ' "'..saymethmin[petaction.saypasmethod]..saypas..'petcom_pow ' .. minpow .. ' Passive"\n')
	cminfile:write(petaction.cmdatk .. ' "'..saymethmin[petaction.sayatkmethod]..sayatk..'petcom_pow ' .. minpow .. ' Attack"\n')
	cminfile:write(petaction.cmdfol .. ' "'..saymethmin[petaction.sayfolmethod]..sayfol..'petcom_pow ' .. minpow .. ' Follow"\n')
	cminfile:write(petaction.cmdsty .. ' "'..saymethmin[petaction.saystymethod]..saysty..'petcom_pow ' .. minpow .. ' Stay"\n')
	cminfile:write(petaction.cmdgoto .. ' "'..saymethmin[petaction.saygomethod]..saygo..'petcom_pow ' .. minpow .. ' Goto"\n')
	cminfile:write(petaction.chattykey..' "tell $name, Non-Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\tier1.txt"\n')
	cltsfile:write(petaction.selall .. ' "'..saymethall[petaction.sayallmethod]..sayall..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\call.txt"\n')
	cltsfile:write(petaction.selmin .. ' "'..saymethmin[petaction.sayminmethod]..saymin..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier1.txt"\n')
	cltsfile:write(petaction.sellts .. ' "'..saymethlts[petaction.sayltsmethod]..saylts..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier2.txt"\n')
	cltsfile:write(petaction.selbos .. ' "'..saymethbos[petaction.saybosmethod]..saybos..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier3.txt"\n')
	cltsfile:write(petaction.setagg .. ' "'..saymethlts[petaction.sayaggmethod]..sayagg..'petcom_pow ' .. ltspow .. ' Aggressive"\n')
	cltsfile:write(petaction.setdef .. ' "'..saymethlts[petaction.saydefmethod]..saydef..'petcom_pow ' .. ltspow .. ' Defensive"\n')
	cltsfile:write(petaction.setpas .. ' "'..saymethlts[petaction.saypasmethod]..saypas..'petcom_pow ' .. ltspow .. ' Passive"\n')
	cltsfile:write(petaction.cmdatk .. ' "'..saymethlts[petaction.sayatkmethod]..sayatk..'petcom_pow ' .. ltspow .. ' Attack"\n')
	cltsfile:write(petaction.cmdfol .. ' "'..saymethlts[petaction.sayfolmethod]..sayfol..'petcom_pow ' .. ltspow .. ' Follow"\n')
	cltsfile:write(petaction.cmdsty .. ' "'..saymethlts[petaction.saystymethod]..saysty..'petcom_pow ' .. ltspow .. ' Stay"\n')
	cltsfile:write(petaction.cmdgoto .. ' "'..saymethlts[petaction.saygomethod]..saygo..'petcom_pow ' .. ltspow .. ' Goto"\n')
	cltsfile:write(petaction.chattykey..' "tell $name, Non-Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\tier2.txt"\n')
	cbosfile:write(petaction.selall .. ' "'..saymethall[petaction.sayallmethod]..sayall..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\call.txt"\n')
	cbosfile:write(petaction.selmin .. ' "'..saymethmin[petaction.sayminmethod]..saymin..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier1.txt"\n')
	cbosfile:write(petaction.sellts .. ' "'..saymethlts[petaction.sayltsmethod]..saylts..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier2.txt"\n')
	cbosfile:write(petaction.selbos .. ' "'..saymethbos[petaction.saybosmethod]..saybos..'bind_load_file_silent ' .. profile.base .. '\\mmbinds\\ctier3.txt"\n')
	cbosfile:write(petaction.setagg .. ' "'..saymethbos[petaction.sayaggmethod]..sayagg..'petcom_pow ' .. bospow .. ' Aggressive"\n')
	cbosfile:write(petaction.setdef .. ' "'..saymethbos[petaction.saydefmethod]..saydef..'petcom_pow ' .. bospow .. ' Defensive"\n')
	cbosfile:write(petaction.setpas .. ' "'..saymethbos[petaction.saypasmethod]..saypas..'petcom_pow ' .. bospow .. ' Passive"\n')
	cbosfile:write(petaction.cmdatk .. ' "'..saymethbos[petaction.sayatkmethod]..sayatk..'petcom_pow ' .. bospow .. ' Attack"\n')
	cbosfile:write(petaction.cmdfol .. ' "'..saymethbos[petaction.sayfolmethod]..sayfol..'petcom_pow ' .. bospow .. ' Follow"\n')
	cbosfile:write(petaction.cmdsty .. ' "'..saymethbos[petaction.saystymethod]..saysty..'petcom_pow ' .. bospow .. ' Stay"\n')
	cbosfile:write(petaction.cmdgoto .. ' "'..saymethbos[petaction.saygomethod]..saygo..'petcom_pow ' .. bospow .. ' Goto"\n')
	cbosfile:write(petaction.chattykey..' "tell $name, Non-Chatty Mode$$bindloadfilesilent '..profile.base..'\\mmbinds\\tier3.txt"\n')
	allfile:close()
	minfile:close()
	ltsfile:close()
	bosfile:close()
	callfile:close()
	cminfile:close()
	cltsfile:close()
	cbosfile:close()
end

function module2.bindisused(profile)
	if profile.petaction == nil then return nil end
	return profile.petaction.enable
end

cbAddModule(module2,"Pet Action Bindings","Mastermind")
