-- CityBinder - Bind File Generator for City of Heroes and City of Villains
-- Copyright (C) 2005  Jeff Sheets

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


local module = {}

local function addSBind(sbinds,n,profile) -- this returns an IUP vbox/hbox to be inserted into the SBind Dialog box
	local sbind = sbinds[n]
	cbToolTip("Choose the Key Combo for this bind")
	local bindkey = cbBindBox("Bind Key",sbind,"Key",function(s) sbind.Key = s return iup.DEFAULT end,function() return "SB: "..sbind.Command end,profile)
	cbToolTip("Enter the Commands to be run when the Key Combo is pressed")
	local bindcmd = cbTextBox("Bind Command",sbind.Command,
		function(_,c,s) sbind.Command = s return iup.DEFAULT end)
	cbToolTip("Click this to Delete this Bind, it will ask for confirmation before deleting")
	local delbtn = cbButton("Delete this Bind",function()
		if iup.Alarm("Confirm Deletion","Are you sure you want to delete this bind?","Yes","No") == 1 then
			table.remove(sbinds,n)
			sbinds.curbind = sbinds.curbind - 1
			if sbinds.curbind == 0 then sbinds.curbind = 1 end
			sbinds.dlg:hide()
			sbinds.dlg:destroy()
			sbinds.dlg = nil
			module.createDialog(sbinds)
			sbinds.dlg:showxy(218,10)
		end end)
	return iup.frame{iup.vbox{bindkey,bindcmd,delbtn},cx = 0, cy = 65 * (n-1)}
end

local function newSBind() -- this returns the default empty Simple Bind table to be inserted into SBinds
	local t = {}
	t.Key = "UNBOUND"
	t.Command = "COMMAND"
	return t
end

function module.createDialog(sbinds,profile)
	local box = {}
	for i = 1,table.getn(sbinds) do
		table.insert(box,addSBind(sbinds,i,profile))
	end
	sbinds.curbind = sbinds.curbind or 1
	cbToolTip("Click this to add a new bind")
	local newbindbtn = cbButton("New Simple Bind",
		function()
			table.insert(sbinds,newSBind())
			sbinds.curbind = table.getn(sbinds)
			sbinds.dlg:hide()
			sbinds.dlg:destroy()
			sbinds.dlg = nil
			module.createDialog(sbinds,profile)
			sbinds.dlg:showxy(218,10)
		end,100)
	local sbEnablePrev = "NO"
	local sbEnableNext = "NO"
	if sbinds.curbind > 1 then sbEnablePrev = "YES" end
	cbToolTip("Click this to go to the previous bind")
	sbinds.prevbind = cbButton("<<",function(self)
			sbinds.curbind = sbinds.curbind - 1
			if sbinds.curbind < 1 then sbinds.curbind = 1 end
			sbinds.zbox.value = box[sbinds.curbind]
			sbinds.poslabel.title = sbinds.curbind.."/"..table.getn(sbinds)
			local sbEnablePrev = "NO"
			if sbinds.curbind > 1 then sbEnablePrev = "YES" end
			sbinds.prevbind.active=sbEnablePrev
			local sbEnableNext = "NO"
			if sbinds.curbind < table.getn(sbinds) then sbEnableNext = "YES" end
			sbinds.nextbind.active=sbEnableNext
		end,25,nil,{active=sbEnablePrev})
	if sbinds.curbind < table.getn(sbinds) then sbEnableNext = "YES" end
	cbToolTip("Click this to go to the previous bind")
	sbinds.nextbind = cbButton(">>",function(self)
			sbinds.curbind = sbinds.curbind + 1
			if sbinds.curbind > table.getn(sbinds) then sbinds.curbind = table.getn(sbinds) end
			sbinds.zbox.value = box[sbinds.curbind]
			sbinds.poslabel.title = sbinds.curbind.."/"..table.getn(sbinds)
			local sbEnablePrev = "NO"
			if sbinds.curbind > 1 then sbEnablePrev = "YES" end
			sbinds.prevbind.active=sbEnablePrev
			local sbEnableNext = "NO"
			if sbinds.curbind < table.getn(sbinds) then sbEnableNext = "YES" end
			sbinds.nextbind.active=sbEnableNext
		end,25,nil,{active=sbEnableNext})
	sbinds.poslabel = iup.label{title = sbinds.curbind.."/"..table.getn(sbinds);rastersize="50x";alignment="ACENTER"}
	box.value = box[sbinds.curbind]
	sbinds.zbox = iup.zbox(box)
	sbinds.dlg = iup.dialog{iup.vbox{sbinds.zbox,iup.hbox{sbinds.prevbind;newbindbtn;sbinds.poslabel;sbinds.nextbind;alignment="ACENTER"};alignment="ACENTER"};title = "General : Simple Binds"}
	sbinds.dlg.close_cb = function(self) sbinds.dlg = nil end
end

function module.bindsettings(profile)
	local sbinds = profile.sbinds
	if sbinds == nil then
		sbinds = {}
		profile.sbinds = sbinds
	end
	if sbinds.dlg then
		sbinds.dlg:show()
	else
		module.createDialog(sbinds,profile)
		sbinds.dlg:showxy(218,10)
	end
end

function module.makebind(profile)
	local resetfile = profile.resetfile
	local sbinds = profile.sbinds
	for i = 1,table.getn(sbinds) do
		resetfile:write(sbinds[i].Key..' "'..sbinds[i].Command..'"\n')
	end
end

function module.bindisused(profile)
	if profile.sbinds == nil then return nil end
	return table.getn(profile.sbinds) > 0
end

cbAddModule(module,"Simple Binds","General")
