-- CityBinder - Bind File Generator for City of Heroes and City of Villains
-- Copyright (C) 2005  Jeff Sheets

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

-- DONE: Next thing to add is a selection of Power Slide, Prestige Power Dash, Rush, Surge_, and Quick.
-- Try to get Superspeed working somehow.  Make sure it gets used when moving, and sprint/PPX is enabled when stationary.  Make an option for always using the Primary power in Run Mode.
-- Add Superjump Binds.  Make it work similar to Hover/Fly, though with Combat Jumping, it may be important to make this a separate toggle, and enforce this.  Copy the blast off binds for jump mode.

local module = {}

function module.bindsettings(profile)
	local SoD = profile.SoD
	if SoD == nil then
		--iup.Message("Notice","Creating Default Speed on Demand Bindings")
		SoD = {}
		profile.SoD = SoD
		SoD.Up = "SPACE"
		SoD.Down = "X"
		SoD.Forward = "W"
		SoD.Back = "S"
		SoD.Left = "A"
		SoD.Right = "D"
		SoD.RunModeKey = "C"
		SoD.FlyModeKey = "F"
		SoD.AutoRunKey = "R"
		SoD.FollowKey = "TILDE"
		SoD.Run = {}
		SoD.Run.Primary = "none"
		SoD.Run.PrimaryNumber = 1
		SoD.Run.Secondary = "Sprint"
		SoD.Run.SecondaryNumber = 1
		SoD.Fly = {}
		SoD.Fly.Hover = nil
		SoD.Fly.Fly = nil
		SoD.Fly.GFly = nil
		SoD.Unqueue = true
		SoD.AutoMouseLook = nil
		SoD.ToggleKey = "LCTRL+M"
		SoD.enable = nil
		SoD.Version = 0.3
	end
	if not SoD.Version then
		SoD.Version = 0.3
		if SoD.Run.SecondaryNumber < 4 then
			SoD.Run.SecondaryNumber = 1
			SoD.Run.Secondary = "Sprint"
		end
		if SoD.Run.SecondaryNumber > 3 then SoD.Run.SecondaryNumber = SoD.Run.SecondaryNumber - 2 end
	end
	--SoD.MouseChord = SoD.MouseChord or nil
	SoD.JumpModeKey = SoD.JumpModeKey or "T"
	SoD.GFlyModeKey =	SoD.GFlyModeKey or "G"
	SoD.Jump = SoD.Jump or {}
	--SoD.Run.UseCamdist = SoD.Run.UseCamdist or nil
	SoD.Run.Camdist = SoD.Run.Camdist or "15"
	--SoD.Fly.UseCamdist = SoD.Fly.UseCamdist or nil
	SoD.Fly.Camdist = SoD.Fly.Camdist or "60"
	SoD.SS = SoD.SS or {}
	if not SoD.SS.SS and SoD.Run.PrimaryNumber == 2 then SoD.SS.SS = true end
	SoD.TTP = SoD.TTP or {}
	SoD.TTP.BindKey = SoD.TTP.BindKey or "LSHIFT+LBUTTON"
	SoD.TTP.ComboKey = SoD.TTP.ComboKey or "LSHIFT"
	SoD.TTP.ResetKey = SoD.TTP.ResetKey or "LCTRL+T"
	SoD.TP = SoD.TP or {}
	SoD.TP.BindKey = SoD.TP.BindKey or "LSHIFT+LBUTTON"
	SoD.TP.ComboKey = SoD.TP.ComboKey or "LSHIFT"
	SoD.TP.ResetKey = SoD.TP.ResetKey or "LCTRL+T"
	--SoD.TP.TP = SoD.TP.TP or "Teleport"
	--SoD.TP.Num = SoD.TP.Num or 1
	SoD.Nova = SoD.Nova or {}
	SoD.Nova.ModeKey = SoD.Nova.ModeKey or "T"
	SoD.Nova.PowerTray = SoD.Nova.PowerTray or "4"
	SoD.Dwarf = SoD.Dwarf or {}
	SoD.Dwarf.ModeKey = SoD.Dwarf.ModeKey or "G"
	SoD.Dwarf.PowerTray = SoD.Dwarf.PowerTray or "5"
	if profile.archetype == "Peacebringer" then
		SoD.Nova.Nova = "Bright Nova"
		SoD.Dwarf.Dwarf = "White Dwarf"
	elseif profile.archetype == "Warshade" then
		SoD.Nova.Nova = "Dark Nova"
		SoD.Dwarf.Dwarf = "Black Dwarf"
	end
	SoD.Detail = SoD.Detail or {}
	SoD.Detail.NormalAmt = SoD.Detail.NormalAmt or "1.0"
	SoD.Detail.MovingAmt = SoD.Detail.MovingAmt or "0.5"
	if SoD.dialog then
		SoD.dialog:show()
	else
		local credits = iup.hbox{iup.fill{};iup.vbox{
			iup.fill{size="5"},
			iup.label{title = "The Speed on Demand Binds"},
			iup.label{title = "were originally Created by Gnarly's"},
			iup.label{title = "Speed on Demand Binds Program, v 3.0"},
			iup.fill{size="5"},
			iup.label{title = "Advanced Teleport Binds by DrLetharga"},
			iup.fill{},
			alignment = "ACENTER"
		};iup.fill{};alignment = "ACENTER",rastersize="200x84"}
		cbToolTip("Check this to Enable the Speed on Demand Binds")
		local sodenable = cbCheckbox("Enable Speed on Demand Binds",SoD.enable,
			function(_,v) if v == 1 then SoD.enable = true else SoD.enable = nil end end)
			
			
		cbToolTip("Choose the Key you use to move Up or Jump")
		local soduphbox = cbBindBox("Up Key",SoD,"Up",function(s) SoD.Up = s end,nil,profile)
		cbToolTip("Choose the Key you use to move Down")
		local soddownhbox = cbBindBox("Down Key",SoD,"Down",function(s) SoD.Down = s end,nil,profile)
		cbToolTip("Choose the Key you use to move Forward")
		local sodforhbox = cbBindBox("Forward Key",SoD,"Forward",function(s) SoD.Forward = s end,nil,profile)
		cbToolTip("Enable this if you want clicking the Left and Right Mouse Buttons to Activate the SoD forward movement")
		local sodmousechord = cbCheckbox("Use Mousechord as SoD Forward",SoD.MouseChord,
			function(_,v) if v == 1 then SoD.MouseChord = true else SoD.MouseChord = nil end end)
		cbToolTip("Choose the Key you use to move Back")
		local sodbackhbox = cbBindBox("Back Key",SoD,"Back",function(s) SoD.Back = s end,nil,profile)
		cbToolTip("Choose the Key you use to move Left")
		local sodlefthbox = cbBindBox("Left Key",SoD,"Left",function(s) SoD.Left = s end,nil,profile)
		cbToolTip("Choose the Key you use to move Right")
		local sodrighthbox = cbBindBox("Right Key",SoD,"Right",function(s) SoD.Right = s end,nil,profile)

		
		cbToolTip("Choose your Sprint Power, default is Sprint")
		local sodrunsechbox = cbListBox("Sprint Power",{"Sprint","Prestige Power Slide","Prestige Power Dash","Prestige Power Rush","Prestige Power Surge ","Prestige Power Quick"},8,SoD.Run.SecondaryNumber,
			function(_,str,i,v) if v == 1 then SoD.Run.Secondary = str SoD.Run.SecondaryNumber = i end end,150,21,50)
		--cbToolTip("Check this unless your character uses a weapon")
		--local sodunqueue = cbCheckbox("Execute powexecunqueue?",SoD.Unqueue,
		--	function(_,v) if v == 1 then SoD.Unqueue = true else SoD.Unqueue = nil end end)
		cbToolTip("Check this if you want the movement keys to initiate Mouselook automatically")
		local sodamlook = cbCheckbox("Auto-Mouselook while moving?",SoD.AutoMouseLook,
			function(_,v) if v == 1 then SoD.AutoMouseLook = true else SoD.AutoMouseLook = nil end end)
		cbToolTip("Choose the Key Combo to Autorun")
		local sodautorunhbox = cbBindBox("AutoRun Key",SoD,"AutoRunKey",function(s) SoD.AutoRunKey = s end,nil,profile)
		cbToolTip("Choose the Key Combo to Follow your target")
		local sodfollowhbox = cbBindBox("Follow Key",SoD,"FollowKey",function(s) SoD.FollowKey = s end,nil,profile)
		cbToolTip("Choose the toggle key to be used to enter or leave Speed on Demand mode")
		local sodtogglehbox = cbBindBox("Normal/SoD Mode Toggle Key",SoD,"ToggleKey",function(s) SoD.ToggleKey = s end,nil,profile)


		cbToolTip("Check this to enable Camera Distance changes when exiting Fly Mode, or stopping a Teleport Chain, and choose the distance in feet")
		local sodruncamdist = cbToggleText("Base Cam Distance",SoD.Run.UseCamdist,SoD.Run.Camdist,
			function(_,v) if v == 1 then SoD.Run.UseCamdist = true else SoD.Run.UseCamdist = nil end end,
			function(_,c,s) SoD.Run.Camdist = s return iup.DEFAULT end)
		cbToolTip("Check this to enable Camera Distance changes when entering Fly Mode, or starting a Teleport Chain, and choose the distance in feet")
		local sodflycamdist = cbToggleText("Moving Cam Distance",SoD.Fly.UseCamdist,SoD.Fly.Camdist,
			function(_,v) if v == 1 then SoD.Fly.UseCamdist = true else SoD.Fly.UseCamdist = nil end end,
			function(_,c,s) SoD.Fly.Camdist = s return iup.DEFAULT end)
		cbToolTip("Check this to enable Detail changes when using Fly Mode, or using the Teleport Bind, and Choose the Normal World Detail level")
		local sodworlddetailnormal = cbToggleText("Normal Detail",SoD.Detail.Enable,SoD.Detail.NormalAmt,
			function(_,v) if v == 1 then SoD.Detail.Enable = true else SoD.Detail.Enable = nil end end,
			function(_,c,s) SoD.Detail.NormalAmt = s return iup.DEFAULT end)
		cbToolTip("Choose the World Detail level to use when Moving if World Detail Changes are enabled")
		local sodworlddetailmoving = cbTextBox("Moving World Detail",SoD.Detail.MovingAmt,
			function(_,c,s) SoD.Detail.MovingAmt = s return iup.DEFAULT end)
		
		
		cbToolTip("Choose the Key Combo to Toggle Super Speed mode")
		local sodrunmodehbox = cbBindBox("Speed Mode Key",SoD,"RunModeKey",function(s) SoD.RunModeKey = s end,nil,profile)
		if not SoD.SS.SS then
			sodrunmodehbox.active="NO"
		end
		cbToolTip("Choose your Primary Run Power, if you only have Sprint, choose None")
		local sodrunprimhbox = cbCheckbox("Character has Super Speed?",SoD.SS.SS,
			function(_,v)
				if v == 1 then
					SoD.Run.Primary = "Super Speed"
					SoD.SS.SS = true
					SoD.Run.PrimaryNumber = 2
					sodrunmodehbox.active="YES"
				else
					SoD.Run.Primary = "None"
					SoD.SS.SS = nil
					SoD.Run.PrimaryNumber = 1
					sodrunmodehbox.active="NO"
				end
			end
		)

		
		cbToolTip("Choose the Key Combo to switch to Jump mode")
		local sodjmpmodehbox = cbBindBox("Jump Mode Key",SoD,"JumpModeKey",function(s) SoD.JumpModeKey = s end,nil,profile)
		cbToolTip("Check this if your Character has the Combat Jumping power")
		local sodhascj = cbCheckbox("Character has Combat Jumping?",SoD.Jump.CJ,
			function(_,v) if v == 1 then SoD.Jump.CJ = true else SoD.Jump.CJ = nil end end)
		if not SoD.Jump.SJ then
			sodhascj.active = "NO"
			sodjmpmodehbox.active = "NO"
		end
		cbToolTip("Check this if your Character has the Super Jump power")
		local sodhasjump = cbCheckbox("Character has Super Jump?",SoD.Jump.SJ,
			function(_,v)
				if v == 1 then
					SoD.Jump.SJ = true
					sodhascj.active = "YES"
					sodjmpmodehbox.active = "YES"
				else
					SoD.Jump.SJ = nil
					sodhascj.active = "NO"
					sodjmpmodehbox.active = "NO"
				end
			end
		)
		

		local HasHoverText = "Character Has Hover?"
		if profile.archetype == "Peacebringer" then
			HasHoverText = "Character Has Combat Flight?"
		end
		cbToolTip("Choose the Key Combo to switch to Fly mode")
		local sodflymodehbox = cbBindBox("Fly Mode Key",SoD,"FlyModeKey",function(s) SoD.FlyModeKey = s end,nil,profile)
		local flyEnabled = function()
			if SoD.Fly.Hover or SoD.Fly.Fly then
				sodflymodehbox.active = "YES"
			else
				sodflymodehbox.active = "NO"
			end
		end
		flyEnabled()
		cbToolTip("Check this if your Character has the Hover power")
		local sodhashover = cbCheckbox(HasHoverText,SoD.Fly.Hover,
			function(_,v) if v == 1 then SoD.Fly.Hover = true else SoD.Fly.Hover = nil end flyEnabled() end)
		cbToolTip("Check this if your Character has the Fly power")
		local sodhasfly = cbCheckbox("Character Has Fly?",SoD.Fly.Fly,
			function(_,v) if v == 1 then SoD.Fly.Fly = true else SoD.Fly.Fly = nil end flyEnabled() end)


		local TPQuestion = "Teleport Bind"
		local sodtpbind
		if profile.archetype == "Peacebringer" then
			TPQuestion = "Dwarf Step Bind"
		elseif profile.archetype == "Warshade" then
			TPQuestion = "Shd/Dwf Step Bind"
		end
		cbToolTip("Set this to the first Key in your Teleport Key Combo, e.g. LSHIFT if the Teleport is bound to LSHIFT+LBUTTON")
		local sodtpcombo = cbBindBox("TP ComboKey",SoD.TP,"ComboKey", function(s) SoD.TP.ComboKey = s end,nil,profile)
		cbToolTip("Choose the Reset Key for the teleport bind")
		local sodtpreset = cbBindBox("TP ResetKey",SoD.TP,"ResetKey",function(s) SoD.TP.ResetKey = s end,nil,profile)
		cbToolTip("Choose the Key Combo to teleport with")
		sodtpbind = cbBindBox(TPQuestion,SoD.TP,"BindKey",function(s) SoD.TP.BindKey = s end,nil,profile)
		if not SoD.TP.Enable then
			sodtpcombo.active = "NO"
			sodtpreset.active = "NO"
			sodtpbind.active = "NO"
		end
		cbToolTip("Chech this to enable the advanced TP binds for the TP power pool, or for Kheldian TP Powers")
		local sodhastp = cbCheckbox("Character Has TP?",SoD.TP.Enable,
			function(_,v)
				if v == 1 then
					SoD.TP.Enable = true
					sodtpcombo.active = "YES"
					sodtpreset.active = "YES"
					sodtpbind.active = "YES"
				else
					SoD.TP.Enable = nil
					sodtpcombo.active = "NO"
					sodtpreset.active = "NO"
					sodtpbind.active = "NO"
				end
			end)


		cbToolTip("Choose the Key Combo to switch to Group Fly mode")
		local sodgflymodehbox = cbBindBox("Group Fly Key",SoD,"GFlyModeKey",function(s) SoD.GFlyModeKey = s end,nil,profile)
		if SoD.Fly.GFly then
			sodgflymodehbox.active = "YES"
		else
			sodgflymodehbox.active = "NO"
		end
		cbToolTip("Check this if your Character has the Group Fly power")
		local sodhasgfly = cbCheckbox("Character Has Group Fly?",SoD.Fly.GFly,
			function(_,v)
				if v == 1 then
					SoD.Fly.GFly = true
					sodgflymodehbox.active = "YES"
				else
					SoD.Fly.GFly = nil
					sodgflymodehbox.active = "NO"
				end
			end
		)


		local TTPQuestion = "Team TP Bind"
		local sodttpbind
		cbToolTip("Set this to the first Key in your Team TP Key Combo, e.g. LSHIFT if the Team TP is bound to LSHIFT+LBUTTON")
		local sodttpcombo = cbBindBox("TTP ComboKey",SoD.TTP,"ComboKey",function(s) SoD.TTP.ComboKey = s end,nil,profile)
		cbToolTip("Choose the Reset Key for the teleport bind")
		local sodttpreset = cbBindBox("TP ResetKey",SoD.TTP,"ResetKey",function(s) SoD.TTP.ResetKey = s end,nil,profile)
		cbToolTip("Choose the Key Combo to teleport with")
		sodttpbind = cbBindBox(TPQuestion,SoD.TTP,"BindKey",function(s) SoD.TTP.BindKey = s end,nil,profile)
		if not SoD.TTP.Enable then
			sodttpcombo.active = "NO"
			sodttpreset.active = "NO"
			sodttpbind.active = "NO"
		end
		cbToolTip("Chech this to enable the advanced TP binds for the Team TP power")
		local sodhasttp = cbCheckbox("Character Has Team TP?",SoD.TTP.Enable,
			function(_,v)
				if v == 1 then
					SoD.TTP.Enable = true
					sodttpcombo.active = "YES"
					sodttpreset.active = "YES"
					sodttpbind.active = "YES"
				else
					SoD.TTP.Enable = nil
					sodttpcombo.active = "NO"
					sodttpreset.active = "NO"
					sodttpbind.active = "NO"
				end
			end)


		local khnovatgl,khnovatray,khdwarftgl,khdwarftray
		if profile.archetype == "Warshade" or profile.archetype == "Peacebringer" then
			cbToolTip("Check this to Enable a toggle key for Nova Form")
			khnovatgl = cbCheckbox("Use Nova Toggle?",SoD.Nova.Enable,
				function(_,v) if v == 1 then SoD.Nova.Enable = true else SoD.Nova.Enable = nil end end)
			cbToolTip("Choose the Key Combo to toggle Nova Form with")
			khnovabnd = cbBindBox("Nova Form Bind",SoD.Nova,"ModeKey",function(s) SoD.Nova.ModeKey = s end,nil,profile)
			cbToolTip("Set this to a powertray to change to when in Nova Form")
			khnovatray = cbTextBox("Nova Power Tray",SoD.Nova.PowerTray,function(_,c,s) SoD.Nova.PowerTray = s return iup.DEFAULT end)
			cbToolTip("Check this to Enable a toggle key for Dwarf Form")
			khdwarftgl = cbCheckbox("Use Dwarf Toggle?",SoD.Dwarf.Enable,
				function(_,v) if v == 1 then SoD.Dwarf.Enable = true else SoD.Dwarf.Enable = nil end end)
			cbToolTip("Choose the Key Combo to toggle Dwarf Form with")
			khdwarfbnd = cbBindBox("Dwarf Form Bind",SoD.Dwarf,"ModeKey",function(s) SoD.Dwarf.ModeKey = s end,nil,profile)
			cbToolTip("Set this to a powertray to change to when in Dwarf Form")
			khdwarftray = cbTextBox("Dwarf Power Tray",SoD.Dwarf.PowerTray,function(_,c,s) SoD.Dwarf.PowerTray = s return iup.DEFAULT end)
		end
		
		
		
		-- Credits and Enable SoD Checkbox go in the same Hbox
		local boxa = iup.vbox{credits,sodenable}
		-- Movement Keys all go in a single frame titled Movement Keys
		local boxb = iup.frame{iup.vbox{soduphbox,soddownhbox,sodforhbox,sodmousechord,sodbackhbox,sodlefthbox,sodrighthbox},
			margin="0x0",Title="Movement Keys"}
		-- General Movement Settings are in the next frame
		--local boxc = iup.frame{iup.vbox{sodrunsechbox,sodunqueue,sodamlook,sodautorunhbox,sodfollowhbox,sodtogglehbox},
		local boxc = iup.frame{iup.vbox{sodrunsechbox,sodamlook,sodautorunhbox,sodfollowhbox,sodtogglehbox},
			margin="0x0",Title="General Settings"}
		-- Detail Settings are placed in the next Frame
		local boxd = iup.frame{iup.vbox{sodruncamdist,sodflycamdist,sodworlddetailnormal,sodworlddetailmoving},
			margin="0x0",Title="Detail Settings"}
			
		-- Next Column, first box is the Superspeed options
		local boxe = iup.frame{iup.vbox{sodrunprimhbox,sodrunmodehbox},margin="0x0",Title="Super Speed on Demand"}
		-- Next is SuperJump Settings
		local boxf = iup.frame{iup.vbox{sodhasjump,sodhascj,sodjmpmodehbox},margin="0x0",Title="Super Jump on Demand"}
		-- Next is Flight stuff.  Only used by non warshades
		local boxg
		if profile.archetype == "Peacebringer" then
			boxg = iup.frame{iup.vbox{sodhashover,sodflymodehbox},margin="0x0",Title="Flight on Demand"}
		elseif not (profile.archetype == "Warshade") then
			boxg = iup.frame{iup.vbox{sodhashover,sodhasfly,sodflymodehbox},margin="0x0",Title="Flight on Demand"}
		end
		-- Next is the Teleport stuff
		local boxh
		boxh = iup.frame{iup.vbox{sodhastp,sodtpbind,sodtpcombo,sodtpreset},margin="0x0",
			Title="Advanced Teleport Binds"}
		-- Next is the Kheldian only Nova/Dwarf Toggles
		local boxi = iup.frame{iup.vbox{khnovatgl,khnovabnd,khnovatray,khdwarftgl,khdwarfbnd,khdwarftray},margin="0x0",
			Title="Nova/Dwarf Form Toggle Settings"}

		-- Third Column is for Team TP and Group Fly
		local boxj = iup.frame{iup.vbox{sodhasgfly,sodgflymodehbox},margin="0x0",Title="Group Fly Mode"}
		local boxk = iup.frame{iup.vbox{sodhasttp,sodttpbind,sodttpcombo,sodttpreset},margin="0x0",
			Title="Team Teleport Binds"}
			
		local soddlg
		if profile.archetype == "Peacebringer" then
			soddlg = iup.dialog{iup.hbox{iup.fill{size="5"},iup.vbox{boxa,iup.fill{size="5"},boxb,iup.fill{size="5"},boxc,iup.fill{size="5"},boxd,iup.fill{size="5"}},iup.fill{size="5"},
				iup.vbox{iup.fill{size="5"},boxe,iup.fill{size="5"},boxf,iup.fill{size="5"},boxg,iup.fill{size="5"},boxh,iup.fill{size="5"},boxi,iup.fill{size="5"}},iup.fill{size="5"}
				},title = "Movement : Speed on Demand"}
		elseif profile.archetype == "Warshade" then
			soddlg = iup.dialog{iup.hbox{iup.fill{size="5"},iup.vbox{boxa,iup.fill{size="5"},boxb,iup.fill{size="5"},boxc,iup.fill{size="5"}},iup.fill{size="5"},
				iup.vbox{iup.fill{size="5"},boxd,iup.fill{size="5"},boxe,iup.fill{size="5"},boxf,iup.fill{size="5"},boxh,iup.fill{size="5"},boxi,iup.fill{size="5"}},iup.fill{size="5"}
				},title = "Movement : Speed on Demand"}
		else
			soddlg = iup.dialog{iup.hbox{iup.fill{size="5"},iup.vbox{boxa,iup.fill{size="5"},boxb,iup.fill{size="5"},boxc,iup.fill{size="5"}},iup.fill{size="5"},
				iup.vbox{iup.fill{size="5"},boxd,iup.fill{size="5"},boxe,iup.fill{size="5"},boxf,iup.fill{size="5"},boxg,iup.fill{size="5"},boxh,iup.fill{size="5"}},iup.fill{size="5"},
				iup.vbox{iup.fill{size="5"},boxj,boxk,iup.fill{size="5"}},iup.fill{size="5"}
				},title = "Movement : Speed on Demand"}
		end
		soddlg:showxy(218,10)
		soddlg.close_cb = function(self) SoD.dialog = nil end
		SoD.dialog = soddlg
	end
end

-- toggleon variation
function actPower_toggle(start,unq,on,...)
	local s = ""
	if on and not (on == "") then
		s = "$$powexectoggleon "..on
	end
	for i,v in ipairs(arg) do
		if type(v) == "table" then
			for j,w in ipairs(v) do
				if not (w == "") then
					s = s.."$$powexectoggleoff "..w.."$$powexectoggleoff "..w
				end
			end
		else
			if not (v == "") then
				s = s.."$$powexectoggleoff "..v.."$$powexectoggleoff "..v
			end
		end
	end
	if start then s = string.sub(s,3,string.len(s)) end
	return s
end

function actPower_name(start,unq,on,...)
	local s = ""
	for i,v in ipairs(arg) do
		if type(v) == "string" then
			if not (v == "") then
				s = s.."$$powexecname "..v
			end
		elseif type(v) == "table" then
			for j,w in ipairs(v) do
				if not (w == "") then
					s = s.."$$powexecname "..w
				end
			end
		end
	end
	if unq and not (s == "") then
		s = s.."$$powexecunqueue"
	end
	if on and not (on == "") then
		--s = s.."$$powexecname "..on.."$$powexecname "..on
		s = s.."$$powexectoggleon "..on
	end
	if start then s = string.sub(s,3,string.len(s)) end
	return s
end

function actPower_hybrid(start,unq,on,...)
	local s = ""
	for i,v in ipairs(arg) do
		if type(v) == "table" then
			for j,w in ipairs(v) do
				if not (w == "") then
					s = s.."$$powexectoggleoff "..w
				end
			end
		else
			if not (v == "") then
				s = s.."$$powexectoggleoff "..v
			end
		end
	end
	if on and not (on == "") then
		s = s.."$$powexecname "..on.."$$powexecname "..on
	end
	if start then s = string.sub(s,3,string.len(s)) end
	return s
end

local actPower = actPower_name
--local actPower = actPower_toggle

function makeBaseModeKey(profile,t,bl,curfile,turnoff,key)
	local bindload
	local SoD = profile.SoD
	if not t.ini then t.ini = "" end
	if bl=="r" then
		bindload=t.bl..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
		local turnon
		--if t.horizkeys > 0 then turnon = "+ "..string.sub(t.on,3,string.len(t.on))..t.sprint..turnoff else turnon = "+ " end
		if t.horizkeys > 0 then turnon = actPower(true,true,t.sprint,turnoff) else turnon = actPower(true,true,nil,turnoff) end
		curfile:write(key..' "'..t.ini..turnon..t.detailhi..t.runcamdist..bindload..'"\n')
	elseif bl=="ar" then
		bindload=t.blgr..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
		curfile:write(key..' "'..t.ini..actPower(true,true,t.sprint,turnoff)..t.detailhi..t.runcamdist.."$$up 0"..t.dow..t.lef..t.rig..bindload..'"\n')
	else
		curfile:write(key..' "'..t.ini..actPower(true,true,t.sprint,turnoff)..t.sprint..t.detailhi..t.runcamdist.."$$up 0"..t.blfr..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
	end
	t.ini = ""
end

function makeSpeedModeKey(profile,t,bl,curfile,turnoff)
	local bindload
	local SoD = profile.SoD
	if not t.ini then t.ini = "" end
	if t.canss > 0 then
		if bl=="s" then
			bindload=t.bls..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			curfile:write(SoD.RunModeKey..' "'..t.ini..actPower(true,true,t.speed,turnoff)..t.detaillo..t.flycamdist..bindload..'"\n')
		elseif bl=="as" then
			bindload=t.blas..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			curfile:write(SoD.RunModeKey..' "'..t.ini..actPower(true,true,t.speed,turnoff)..'$$up 0'..t.detaillo..t.flycamdist..t.dow..t.lef..t.rig..bindload..'"\n')
		else
			curfile:write(SoD.RunModeKey..' "'..t.ini..actPower(true,true,t.speed,turnoff)..'$$up 0'..t.detaillo..t.flycamdist..t.blfs..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		end
	end
	t.ini = ""
end

function makeJumpModeKey(profile,t,bl,curfile,turnoff,fbl)
	local bindload, filename, tglfile
	local SoD = profile.SoD
	if t.canjmp > 0 then
		if bl=="j" then
			bindload=t.blj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			local a
			if (t.horizkeys+t.space)>0 then a = actPower(nil,true,t.jump,turnoff).."$$up 1" else a = actPower(nil,true,t.cjmp,turnoff) end
			filename = fbl..t.space..t.X..t.W..t.S..t.A..t.D.."j.txt"
			tglfile = cbOpen(filename,"w")
			tglfile:write(SoD.JumpModeKey..' "+ '..a..t.detaillo..t.flycamdist..bindload..'"\n')
			tglfile:close()
			curfile:write(SoD.JumpModeKey..' "+ $$bindloadfilesilent'..filename..'"\n')
		elseif bl=="aj" then
			bindload=t.blaj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			filename = fbl..t.space..t.X..t.W..t.S..t.A..t.D.."j.txt"
			tglfile = cbOpen(filename,"w")
			tglfile:write(SoD.JumpModeKey..' "+ '..actPower(nil,true,t.jump,turnoff).."$$up 1"..t.detaillo..t.flycamdist..t.dow..t.lef..t.rig..bindload..'"\n')
			tglfile:close()
			curfile:write(SoD.JumpModeKey..' "+ $$bindloadfilesilent'..filename..'"\n')
		else
			filename = fbl..t.space..t.X..t.W..t.S..t.A..t.D.."j.txt"
			tglfile = cbOpen(filename,"w")
			tglfile:write(SoD.JumpModeKey..' "+ '..actPower(nil,true,t.jump,turnoff).."$$up 1"..t.detaillo..t.flycamdist..t.blfj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
			tglfile:close()
			curfile:write(SoD.JumpModeKey..' "+ $$bindloadfilesilent'..filename..'"\n')
		end
	end
end

function makeFlyModeKey(profile,t,bl,curfile,turnoff)
	local bindload, turnon
	local SoD = profile.SoD
	if t.canhov+t.canfly > 0 then
		if bl=="bo" then
			bindload=t.blbo..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			curfile:write(SoD.FlyModeKey..' "'..actPower(true,true,t.flyx,turnoff).."$$up 1$$down 0"..t.detaillo..t.flycamdist..bindload..'"\n')
		elseif bl=="a" then
			bindload=t.bla..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			if t.tkeys==0 then turnon=t.hover else turnon=t.flyx end
			curfile:write(SoD.FlyModeKey..' "'..actPower(true,true,turnon,turnoff)..t.detaillo..t.flycamdist..t.dow..t.lef..t.rig..bindload..'"\n')
		elseif bl=="af" then
			bindload=t.blaf..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			curfile:write(SoD.FlyModeKey..' "'..actPower(true,true,t.flyx,turnoff)..t.detaillo..t.flycamdist..t.dow..t.lef..t.rig..bindload..'"\n')
		else
			curfile:write(SoD.FlyModeKey..' "'..actPower(true,true,t.flyx,turnoff)..t.detaillo..t.flycamdist..t.blff..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		end
	end
end

function makeGFlyModeKey(profile,t,bl,curfile,turnoff)
	local bindload
	local SoD = profile.SoD
	if t.cangfly > 0 then
		if bl=="gbo" then
			bindload=t.blgbo..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			curfile:write(SoD.GFlyModeKey..' "up 1'..actPower(nil,true,t.gfly,turnoff)..t.detaillo..t.flycamdist..bindload..'"\n')
		elseif bl=="gaf" then
			bindload=t.blgaf..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
			curfile:write(SoD.GFlyModeKey..' "'..actPower(true,true,t.gfly,turnoff)..t.detaillo..t.flycamdist..t.dow..t.lef..t.rig..bindload..'"\n')
		else
			curfile:write(SoD.GFlyModeKey..' "'..actPower(true,true,t.gfly,turnoff)..t.detaillo..t.flycamdist..t.blgff..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		end
	end
end

function makeBaseFile(profile,t)
	--This function creates the bindfiles needed for the basic no travel power SoD system.  It uses Sprint, and only Sprint.
	local bindload, filename, curfile
	local SoD = profile.SoD
	filename=t.path..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	curfile:write(profile.ResetKey..' "up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.sprint)..'$$tell $name, SoD Binds Reset$$bind_load_file_silent '..t.path..'000000.txt"\n')

	if t.tkeys == 0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.sprint)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
		t.toggleon = t.mlon
	else
		t.toggleon = ""
	end

	if t.tkeys == 1 and t.space == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	bindload = t.bl..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')

	if t.tkeys == 1 and t.X == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	bindload = t.bl..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')

	if t.horizkeys == 0 then t.ml = t.mlon t.toggleon = t.sprint else t.ml = "" t.toggleon = nil end
	
	if t.horizkeys == 1 and t.W == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.sprint else t.toggleoff = nil end
	if t.horizkeys == 1 and t.W == 1 and t.tkeys > 1 then t.toggleoff = t.sprint end
	bindload = t.bl..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn..t.up..t.dow..t.forx..t.bac..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.up..t.dow..t.forx..t.bac..t.rig..t.lef..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n') -- trying to see if switching some of the bindtext works for mousechord
	end
	
	if t.horizkeys == 1 and t.S == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.sprint else t.toggleoff = nil end
	if t.horizkeys == 1 and t.S == 1 and t.tkeys > 1 then t.toggleoff = t.sprint end
	bindload = t.bl..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn..t.up..t.dow..t.forw..t.bacx..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	
	if t.horizkeys == 1 and t.A == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.sprint else t.toggleoff = nil end
	if t.horizkeys == 1 and t.A == 1 and t.tkeys > 1 then t.toggleoff = t.sprint end
	bindload = t.bl..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lefx..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	
	if t.horizkeys == 1 and t.D == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.sprint else t.toggleoff = nil end
	if t.horizkeys == 1 and t.D == 1 and t.tkeys > 1 then t.toggleoff = t.sprint end
	bindload = t.bl..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lef..t.rigx..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	
	makeFlyModeKey(profile,t,"bo",curfile,t.sprint)
	makeGFlyModeKey(profile,t,"gbo",curfile,t.sprint)
	makeSpeedModeKey(profile,t,"s",curfile,t.sprint)
	makeJumpModeKey(profile,t,"j",curfile,t.sprint,t.path)
	
	--if cancj+canjmp > 0 then
	--	bindload=blj..spc..X..W..S..A..D..".txt"
	--	--curfile:write(SoD.JumpModeKey..' "'..turn..sprint..speed..jump..jump..'$$t $name, Jumpmode$$'..detaillo..flycamdist..bindload..'"\n')
	--	curfile:write(SoD.JumpModeKey..' "'..sprint..speed..jump..cjmp..cjmp..'$$'..detaillo..flycamdist..bindload..'"\n')
	--end
	
	bindload = t.blgr..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "forward 1$$backward 0'..t.up..t.dow..t.lef..t.rig..t.mlon..actPower(nil,true,t.sprint)..bindload..'"\n')
	
	--if t.horizkeys == 0 then t.toggleon = actPower(nil,true,t.sprint) else t.toggleon= "" end
	curfile:write(SoD.FollowKey..' "follow'..actPower(nil,true,t.sprint)..t.blfr..t.space..t.X..t.W..t.S..t.A..t.D..'.txt"\n')

	curfile:close()

--AutoRun Binds
	filename=t.pathgr..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
	
	curfile:write(profile.ResetKey..' "up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.sprint)..'$$tell $name, SoD Binds Reset$$bind_load_file_silent '..t.path..'000000.txt"\n')
	
	if t.tkeys == 0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.sprint)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
	end
	
	bindload=t.blgr..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow.."$$backward 0"..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	bindload=t.blgr..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx.."$$backward 0"..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	if t.W==1 then
		t.toggleon="$$backward 0"..actPower(nil,true,t.sprint)
		bindload=t.blgr..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 1$$backward 0"..actPower(nil,true,t.sprint)
		bindload=t.bl..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	end
	curfile:write(SoD.Forward..' "'..t.turn..t.toggleon..t.lef..t.rig..t.mlon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.toggleon..t.rig..t.lef..t.mlon..bindload..'"\n')
	end
	--curfile:write('mousechord "'..turn..toggleon..lef..rig..mlon..bindload..'"\n')
	
	if t.S==1 then
		t.toggleon="$$backward 0"..actPower(nil,true,t.sprint)
		bindload=t.blgr..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 0$$backward 1"..actPower(nil,true,t.sprint)
		bindload=t.bl..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	end
	curfile:write(SoD.Back..' "'..t.turn..t.toggleon..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	bindload=t.blgr..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$backward 0"..t.lefx..t.rig..t.mlon..t.on..t.sprint..bindload..'"\n')

	bindload=t.blgr..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$backward 0"..t.lef..t.rigx..t.mlon..t.on..t.sprint..bindload..'"\n')

	makeFlyModeKey(profile,t,"af",curfile,t.sprint)
	makeGFlyModeKey(profile,t,"gaf",curfile,t.sprint)
	makeSpeedModeKey(profile,t,"as",curfile,t.sprint)
	makeJumpModeKey(profile,t,"aj",curfile,t.sprint,t.pathgr)
	--makeJumpModeKey(profile,t,"aj",curfile,t.sprint,t.pathgr)
	
	if t.tkeys>0 then t.toggleon=t.mlon..actPower(nil,true,t.sprint) else t.toggleon=t.mloff..actPower(nil,true,nil,t.sprint) end
	bindload=t.bl..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "'..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')

	curfile:write(SoD.FollowKey.." nop\n")
	
	curfile:close()

--FollowRun Binds
	filename=t.pathfr..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.sprint).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.path..'000000.txt"\n')
	
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.sprint).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
	
	if t.space==1 then bindload=t.blfr.."0"..t.X..t.W..t.S..t.A..t.D..".txt" else bindload=t.bl.."1"..t.X..t.W..t.S..t.A..t.D..".txt" end
	if t.space==1 then t.toggleon="" else t.toggleon=t.upx..t.dow..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Up..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.X==1 then bindload=t.blfr..t.space.."0"..t.W..t.S..t.A..t.D..".txt" else bindload=t.bl..t.space.."1"..t.W..t.S..t.A..t.D..".txt" end
	if t.X==1 then t.toggleon="" else t.toggleon=t.up..t.dowx..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Down..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.W==1 then bindload=t.blfr..t.space..t.X.."0"..t.S..t.A..t.D..".txt" else bindload=t.bl..t.space..t.X.."1"..t.S..t.A..t.D..".txt" end
	if t.W==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.lef..t.rig end
	curfile:write(SoD.Forward..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	if SoD.MouseChord then
		if t.W==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.rig..t.lef end
		curfile:write('mousechord "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	end
	
	if t.S==1 then bindload=t.blfr..t.space..t.X..t.W.."0"..t.A..t.D..".txt" else bindload=t.bl..t.space..t.X..t.W.."1"..t.A..t.D..".txt" end
	if t.S==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bacx..t.lef..t.rig end
	curfile:write(SoD.Back..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.A==1 then bindload=t.blfr..t.space..t.X..t.W..t.S.."0"..t.D..".txt" else bindload=t.bl..t.space..t.X..t.W..t.S.."1"..t.D..".txt" end
	if t.A==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lefx..t.rig end
	curfile:write(SoD.Left..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.D==1 then bindload=t.blfr..t.space..t.X..t.W..t.S..t.A.."0"..".txt" else bindload=t.bl..t.space..t.X..t.W..t.S..t.A.."1"..".txt" end
	if t.D==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lef..t.rigx end
	curfile:write(SoD.Right..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	makeFlyModeKey(profile,t,"ff",curfile,t.sprint)
	makeGFlyModeKey(profile,t,"gff",curfile,t.sprint)
	makeSpeedModeKey(profile,t,"fs",curfile,t.sprint)
	makeJumpModeKey(profile,t,"fj",curfile,t.sprint,t.pathfr)
	--makeJumpModeKey(profile,t,"fj",curfile,t.sprint,t.pathfr)
	
	curfile:write(SoD.AutoRunKey.." nop\n")
	
	if t.tkeys==0 then t.toggleoff=actPower(nil,true,nil,t.sprint) else t.toggleoff="" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.toggleoff..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.bl..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
	
	curfile:close()
end

function makeSpeedFile(profile,t)
	--This function creates the bindfiles needed for the SuperSpeed SoD system.  It uses SuperSpeed, and only SuperSpeed.
	local bindload, filename, curfile
	local SoD = profile.SoD
	filename=t.paths..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	curfile:write(profile.ResetKey..' "up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,t.speed)..'$$tell $name, SoD Binds Reset$$bind_load_file_silent '..t.paths..'000000.txt"\n')

	if t.tkeys == 0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.speed)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
		t.toggleon = t.mlon..actPower(nil,true,t.speed)
	else
		--t.toggleon = actPower(nil,true,t.speed)
		t.toggleon = ""
	end

	if t.tkeys == 1 and t.space == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	bindload = t.bls..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')

	if t.tkeys == 1 and t.X == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	bindload = t.bls..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')

	--if t.horizkeys == 0 then t.toggleon = t.mlon..actPower(nil,true,t.speed) else t.toggleon = actPower(nil,true,t.speed) end
	if t.horizkeys == 0 then t.toggleon = t.mlon..actPower(nil,true,t.speed) else t.toggleon = "" end
	
	if t.horizkeys == 1 and t.W == 1 and t.tkeys == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	--if t.horizkeys == 1 and t.W == 1 and t.tkeys > 1 then t.toggleoff = tue end
	bindload = t.bls..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn..t.up..t.dow..t.forx..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.up..t.dow..t.forx..t.bac..t.rig..t.lef..t.toggleon..t.toggleoff..bindload..'"\n') -- trying to see if switching some of the bindtext works for mousechord
	end
	
	if t.horizkeys == 1 and t.S == 1 and t.tkeys == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	--if t.horizkeys == 1 and t.S == 1 and t.tkeys > 1 then t.toggleoff = t.speed..t.unqueue end
	bindload = t.bls..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn..t.up..t.dow..t.forw..t.bacx..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
	
	if t.horizkeys == 1 and t.A == 1 and t.tkeys == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	--if t.horizkeys == 1 and t.A == 1 and t.tkeys > 1 then t.toggleoff = t.speed..t.unqueue end
	bindload = t.bls..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lefx..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
	
	if t.horizkeys == 1 and t.D == 1 and t.tkeys == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	--if t.horizkeys == 1 and t.D == 1 and t.tkeys > 1 then t.toggleoff = t.speed..t.unqueue end
	bindload = t.bls..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lef..t.rigx..t.toggleon..t.toggleoff..bindload..'"\n')
	
	makeFlyModeKey(profile,t,"bo",curfile,t.speed)
	makeGFlyModeKey(profile,t,"gbo",curfile,t.speed)
	makeBaseModeKey(profile,t,"r",curfile,t.speed,SoD.RunModeKey)
	makeJumpModeKey(profile,t,"j",curfile,t.speed,t.paths)
	
	--if cancj+canjmp > 0 then
	--	bindload=blj..spc..X..W..S..A..D..".txt"
	--	--curfile:write(SoD.JumpModeKey..' "'..turn..sprint..speed..jump..jump..'$$t $name, Jumpmode$$'..detaillo..flycamdist..bindload..'"\n')
	--	curfile:write(SoD.JumpModeKey..' "'..sprint..speed..jump..cjmp..cjmp..'$$'..detaillo..flycamdist..bindload..'"\n')
	--end
	
	bindload = t.blas..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "forward 1$$backward 0'..t.up..t.dow..t.lef..t.rig..t.mlon..actPower(nil,true,t.speed)..bindload..'"\n')
	
	curfile:write(SoD.FollowKey..' "follow'..actPower(nil,true,t.speed)..t.blfs..t.space..t.X..t.W..t.S..t.A..t.D..'.txt"\n')

	curfile:close()

--AutoRun Binds
	filename=t.pathas..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
	
	curfile:write(profile.ResetKey..' "up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,t.speed)..'$$tell $name, SoD Binds Reset$$bind_load_file_silent '..t.paths..'000000.txt"\n')
	
	if t.tkeys == 0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.speed)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
	end
	
	bindload=t.blas..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow.."$$backward 0"..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	bindload=t.blas..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx.."$$backward 0"..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	if t.W==1 then
		t.toggleon="$$backward 0"
		bindload=t.blas..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 1$$backward 0"
		bindload=t.bls..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	end
	curfile:write(SoD.Forward..' "'..t.turn..t.toggleon..t.lef..t.rig..t.mlon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.toggleon..t.rig..t.lef..t.mlon..bindload..'"\n')
	end
	--curfile:write('mousechord "'..turn..toggleon..lef..rig..mlon..bindload..'"\n')
	
	if t.S==1 then
		t.toggleon="$$backward 0"
		bindload=t.blas..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 0$$backward 1"
		bindload=t.bls..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	end
	curfile:write(SoD.Back..' "'..t.turn..t.toggleon..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	bindload=t.blas..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$backward 0"..t.lefx..t.rig..t.mlon..bindload..'"\n')

	bindload=t.blas..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$backward 0"..t.lef..t.rigx..t.mlon..bindload..'"\n')

	makeFlyModeKey(profile,t,"af",curfile,t.speed)
	makeGFlyModeKey(profile,t,"gaf",curfile,t.speed)
	makeBaseModeKey(profile,t,"ar",curfile,t.speed,SoD.RunModeKey)
	makeJumpModeKey(profile,t,"aj",curfile,t.speed,t.pathas)
	
	if t.tkeys>0 then t.toggleon=t.mlon else t.toggleon=t.mloff end
	--if t.tkeys==0 then t.toggleoff=t.speed..t.unqueue else t.toggleoff="" end
	bindload=t.bls..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "'..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..actPower(nil,true,t.speed)..bindload..'"\n')

	curfile:write(SoD.FollowKey.." nop\n")
	
	curfile:close()

--FollowRun Binds
	filename=t.pathfs..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,t.speed).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.paths..'000000.txt"\n')
	
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.speed).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
	
	if t.space==1 then bindload=t.blfs.."0"..t.X..t.W..t.S..t.A..t.D..".txt" else bindload=t.bls.."1"..t.X..t.W..t.S..t.A..t.D..".txt" end
	if t.space==1 then t.toggleon="" else t.toggleon=string.sub(t.upx,3,string.len(t.upx))..t.dow..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Up..' "'..t.toggleon..bindload..'"\n')
	
	if t.X==1 then bindload=t.blfs..t.space.."0"..t.W..t.S..t.A..t.D..".txt" else bindload=t.bls..t.space.."1"..t.W..t.S..t.A..t.D..".txt" end
	if t.X==1 then t.toggleon="" else t.toggleon=string.sub(t.up,3,string.len(t.up))..t.dowx..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Down..' "'..t.toggleon..bindload..'"\n')
	
	if t.W==1 then bindload=t.blfs..t.space..t.X.."0"..t.S..t.A..t.D..".txt" else bindload=t.bls..t.space..t.X.."1"..t.S..t.A..t.D..".txt" end
	if t.W==1 then t.toggleon="" else t.toggleon=string.sub(t.up,3,string.len(t.up))..t.dow..t.forx..t.bac..t.lef..t.rig end
	curfile:write(SoD.Forward..' "'..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		if t.W==1 then t.toggleon="" else t.toggleon=string.sub(t.up,3,string.len(t.up))..t.dow..t.forx..t.bac..t.rig..t.lef end
		curfile:write('mousechord "'..t.toggleon..bindload..'"\n')
	end
	
	if t.S==1 then bindload=t.blfs..t.space..t.X..t.W.."0"..t.A..t.D..".txt" else bindload=t.bls..t.space..t.X..t.W.."1"..t.A..t.D..".txt" end
	if t.S==1 then t.toggleon="" else t.toggleon=string.sub(t.up,3,string.len(t.up))..t.dow..t.forw..t.bacx..t.lef..t.rig end
	curfile:write(SoD.Back..' "'..t.toggleon..bindload..'"\n')
	
	if t.A==1 then bindload=t.blfs..t.space..t.X..t.W..t.S.."0"..t.D..".txt" else bindload=t.bls..t.space..t.X..t.W..t.S.."1"..t.D..".txt" end
	if t.A==1 then t.toggleon="" else t.toggleon=string.sub(t.up,3,string.len(t.up))..t.dow..t.forw..t.bac..t.lefx..t.rig end
	curfile:write(SoD.Left..' "'..t.toggleon..bindload..'"\n')
	
	if t.D==1 then bindload=t.blfs..t.space..t.X..t.W..t.S..t.A.."0"..".txt" else bindload=t.bls..t.space..t.X..t.W..t.S..t.A.."1"..".txt" end
	if t.D==1 then t.toggleon="" else t.toggleon=string.sub(t.up,3,string.len(t.up))..t.dow..t.forw..t.bac..t.lef..t.rigx end
	curfile:write(SoD.Right..' "'..t.toggleon..bindload..'"\n')
	
	makeFlyModeKey(profile,t,"ff",curfile,t.speed)
	makeGFlyModeKey(profile,t,"gff",curfile,t.speed)
	makeBaseModeKey(profile,t,"fr",curfile,t.speed,SoD.RunModeKey)
	makeJumpModeKey(profile,t,"fj",curfile,t.speed,t.pathfs)
	
	curfile:write(SoD.AutoRunKey.." nop\n")
	
	if t.tkeys==0 then t.toggleoff=actPower(nil,true,t.speed) else t.toggleoff="" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.toggleoff..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.bls..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
	
	curfile:close()
end

function makeJumpFile(profile,t)
	--This function creates the bindfiles needed for the SuperSpeed SoD system.  It uses SuperJump, and Combat Jumping.
	local bindload, filename, curfile, tglfile
	local SoD = profile.SoD
	local jup
	filename=t.pathj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
	t.jkeys = t.horizkeys+t.space
	
	local aj
	if t.cancj == 1 then aj=t.cjmp end
	if t.canjmp == 1 then aj=t.jump end

	curfile:write(profile.ResetKey..' "up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,t.cjmp,t.jump)..'$$tell $name, SoD Binds Reset$$bind_load_file_silent '..t.pathj..'000000.txt"\n')

	if t.jkeys == 0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.cjmp,t.jump)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
		t.ml = t.mlon
		t.toggleon = t.jump
	else
		t.ml = ""
		t.toggleon = nil
	end
	--if t.horizkeys == 0 then t.toggleon = t.mlon else t.toggleon = "" end

	--if t.horizkeys == 1 and t.W == 1 and t.tkeys == 1 then t.toggleoff = t.mloff..t.sprint..t.unqueue else t.toggleoff = "" end
	--if t.horizkeys == 1 and t.W == 1 and t.tkeys > 1 then t.toggleoff = t.sprint..t.unqueue end
	if t.tkeys == 1 and t.space == 1 then t.ml = t.mloff t.toggleoff = t.jump t.toggleon = t.cjmp else t.toggleoff = nil t.toggleon = t.jump end
	bindload = t.blj..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	if t.tkeys == 1 and t.space == 1 then jup="$$up 0" else jup="$$up 1" end
	curfile:write(SoD.Up..' "'..t.turn..jup..t.dow..t.forw..t.bac..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')

	--if t.tkeys == 1 and t.X == 1 then t.toggleoff = t.mloff else t.toggleoff = "" end
	--bindload = t.bls..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	--curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
	curfile:write(SoD.Down..' nop\n')

	if t.jkeys==0 then t.toggleon = t.jump else t.toggleon = nil end
	if t.horizkeys == 1 and t.W == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.jump t.toggleon = t.cjmp else t.toggleoff = nil end
	if t.tkeys == 1 and t.W == 1 then jup="$$up 0" else jup="$$up 1" end
	--if t.horizkeys == 1 and t.W == 1 and t.tkeys > 1 then t.toggleoff = tue end
	bindload = t.blj..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn..jup..t.dow..t.forx..t.bac..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..jup..t.dow..t.forx..t.bac..t.rig..t.lef..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n') -- trying to see if switching some of the bindtext works for mousechord
	end
	
	if t.jkeys==0 then t.toggleon = t.jump else t.toggleon = nil end
	if t.horizkeys == 1 and t.S == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.jump t.toggleon = t.cjmp else t.toggleoff = nil end
	if t.tkeys == 1 and t.S == 1 then jup="$$up 0" else jup="$$up 1" end
	--if t.horizkeys == 1 and t.S == 1 and t.tkeys > 1 then t.toggleoff = t.speed..t.unqueue end
	bindload = t.blj..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn..jup..t.dow..t.forw..t.bacx..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	
	if t.jkeys==0 then t.toggleon = t.jump else t.toggleon = nil end
	if t.horizkeys == 1 and t.A == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.jump t.toggleon = t.cjmp else t.toggleoff = nil end
	if t.tkeys == 1 and t.A == 1 then jup="$$up 0" else jup="$$up 1" end
	--if t.horizkeys == 1 and t.A == 1 and t.tkeys > 1 then t.toggleoff = t.speed..t.unqueue end
	bindload = t.blj..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..jup..t.dow..t.forw..t.bac..t.lefx..t.rig..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	
	if t.jkeys==0 then t.toggleon = t.jump else t.toggleon = nil end
	if t.horizkeys == 1 and t.D == 1 and t.tkeys == 1 then t.ml = t.mloff t.toggleoff = t.jump t.toggleon = t.cjmp else t.toggleoff = nil end
	if t.tkeys == 1 and t.D == 1 then jup="$$up 0" else jup="$$up 1" end
	--if t.horizkeys == 1 and t.D == 1 and t.tkeys > 1 then t.toggleoff = t.speed..t.unqueue end
	bindload = t.blj..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..jup..t.dow..t.forw..t.bac..t.lef..t.rigx..t.ml..actPower(nil,true,t.toggleon,t.toggleoff)..bindload..'"\n')
	
	makeFlyModeKey(profile,t,"bo",curfile,t.jump)
	makeGFlyModeKey(profile,t,"gbo",curfile,t.jump)
	filename=t.pathj..t.space..t.X..t.W..t.S..t.A..t.D.."t.txt"
	tglfile = cbOpen(filename,"w")
	t.ini = "+ "
	makeBaseModeKey(profile,t,"r",tglfile,t.jump,SoD.JumpModeKey)
	tglfile:close()
	if t.space == 1 then jup="$$up 1" else jup="$$up 0" end
	curfile:write(SoD.JumpModeKey..' "'..t.turn..jup..actPower(nil,true,t.cjmp)..'$$bindloadfilesilent'..filename..'"\n')
	if t.canss>0 then
		filename=t.pathj..t.space..t.X..t.W..t.S..t.A..t.D.."s.txt"
		tglfile = cbOpen(filename,"w")
		t.ini = "+ "
		makeSpeedModeKey(profile,t,"s",tglfile,t.jump)
		tglfile:close()
		curfile:write(SoD.RunModeKey..' "'..t.turn..jup..actPower(nil,true,t.cjmp)..'$$bindloadfilesilent'..filename..'"\n')
	end
	
	bindload = t.blaj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "forward 1$$backward 0$$up 1'..t.dow..t.lef..t.rig..t.mlon..actPower(nil,true,aj)..bindload..'"\n')
	
	--if t.horizkeys == 0 then t.toggleon = ajon else t.toggleon= "" end
	curfile:write(SoD.FollowKey..' "follow'..actPower(nil,true,aj)..'$$up 1'..t.blfj..t.space..t.X..t.W..t.S..t.A..t.D..'.txt"\n')

	curfile:close()

--AutoRun Binds
	filename=t.pathaj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
	
	curfile:write(profile.ResetKey..' "up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,t.cjmp,t.jump)..'$$tell $name, SoD Binds Reset$$bind_load_file_silent '..t.pathj..'000000.txt"\n')
	
	if t.tkeys == 0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.cjmp,t.jump)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
	end
	
	bindload=t.blaj..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow.."$$backward 0"..t.lef..t.rig..t.mlon..actPower(nil,true,aj)..bindload..'"\n')
	
	bindload=t.blaj..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx.."$$backward 0"..t.lef..t.rig..t.mlon..actPower(nil,true,aj)..bindload..'"\n')
	
	if t.W==1 then
		t.toggleon="$$backward 0"..actPower(nil,true,aj)
		bindload=t.blaj..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 1$$backward 0"..actPower(nil,true,aj)
		bindload=t.blj..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	end
	curfile:write(SoD.Forward..' "'..t.turn..t.toggleon..t.lef..t.rig..t.mlon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.toggleon..t.rig..t.lef..t.mlon..bindload..'"\n')
	end
	--curfile:write('mousechord "'..turn..toggleon..lef..rig..mlon..bindload..'"\n')
	
	if t.S==1 then
		t.toggleon="$$backward 0"..actPower(nil,true,aj)
		bindload=t.blaj..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 0$$backward 1"..actPower(nil,true,aj)
		bindload=t.blj..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	end
	curfile:write(SoD.Back..' "'..t.turn..t.toggleon..t.lef..t.rig..t.mlon..bindload..'"\n')
	
	bindload=t.blaj..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$backward 0"..t.lefx..t.rig..t.mlon..actPower(nil,true,aj)..bindload..'"\n')

	bindload=t.blaj..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$backward 0"..t.lef..t.rigx..t.mlon..actPower(nil,true,aj)..bindload..'"\n')

	makeFlyModeKey(profile,t,"af",curfile,t.jump)
	makeGFlyModeKey(profile,t,"gaf",curfile,t.jump)
	filename=t.pathaj..t.space..t.X..t.W..t.S..t.A..t.D.."t.txt"
	tglfile = cbOpen(filename,"w")
	t.ini = "+ "
	makeBaseModeKey(profile,t,"ar",tglfile,t.jump,SoD.JumpModeKey)
	tglfile:close()
	curfile:write(SoD.JumpModeKey..' "'..t.turn..actPower(nil,true,t.cjmp)..'$$bindloadfilesilent'..filename..'"\n')
	--makeBaseModeKey(profile,t,"ar",curfile,t.speed,SoD.RunModeKey)
	if t.canss>0 then
		filename=t.pathaj..t.space..t.X..t.W..t.S..t.A..t.D.."s.txt"
		tglfile = cbOpen(filename,"w")
		t.ini = "+ "
		makeSpeedModeKey(profile,t,"as",tglfile,t.jump)
		tglfile:close()
		curfile:write(SoD.RunModeKey..' "'..t.turn..jup..actPower(nil,true,t.cjmp)..'$$bindloadfilesilent'..filename..'"\n')
	end
	
	if t.tkeys>0 then t.toggleon=t.mlon..actPower(nil,true,aj) else t.toggleon=t.mloff..actPower(nil,true,t.cjmp,t.jump) end
	bindload=t.blj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	if t.jkeys>0 then jup="up 1" else jup="up 0" end
	curfile:write(SoD.AutoRunKey..' "'..jup..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')

	curfile:write(SoD.FollowKey.." nop\n")
	
	curfile:close()

--FollowRun Binds
	filename=t.pathfj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,t.cjmp,t.jump).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.pathj..'000000.txt"\n')
	
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.cjmp,t.jump).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
	
	if t.space==1 then bindload=t.blfj.."0"..t.X..t.W..t.S..t.A..t.D..".txt" else bindload=t.blj.."1"..t.X..t.W..t.S..t.A..t.D..".txt" end
	if t.space==1 then t.toggleon="" else t.toggleon=t.upx..t.dow..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Up..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.X==1 then bindload=t.blfj..t.space.."0"..t.W..t.S..t.A..t.D..".txt" else bindload=t.blj..t.space.."1"..t.W..t.S..t.A..t.D..".txt" end
	if t.X==1 then t.toggleon="" else t.toggleon=t.up..t.dowx..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Down..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.W==1 then bindload=t.blfj..t.space..t.X.."0"..t.S..t.A..t.D..".txt" else bindload=t.blj..t.space..t.X.."1"..t.S..t.A..t.D..".txt" end
	if t.W==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.lef..t.rig end
	curfile:write(SoD.Forward..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	if SoD.MouseChord then
		if t.W==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.rig..t.lef end
		curfile:write('mousechord "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	end
	
	if t.S==1 then bindload=t.blfj..t.space..t.X..t.W.."0"..t.A..t.D..".txt" else bindload=t.blj..t.space..t.X..t.W.."1"..t.A..t.D..".txt" end
	if t.S==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bacx..t.lef..t.rig end
	curfile:write(SoD.Back..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.A==1 then bindload=t.blfj..t.space..t.X..t.W..t.S.."0"..t.D..".txt" else bindload=t.blj..t.space..t.X..t.W..t.S.."1"..t.D..".txt" end
	if t.A==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lefx..t.rig end
	curfile:write(SoD.Left..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	if t.D==1 then bindload=t.blfj..t.space..t.X..t.W..t.S..t.A.."0"..".txt" else bindload=t.blj..t.space..t.X..t.W..t.S..t.A.."1"..".txt" end
	if t.D==1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lef..t.rigx end
	curfile:write(SoD.Right..' "'..string.sub(t.toggleon,3,string.len(t.toggleon))..bindload..'"\n')
	
	makeFlyModeKey(profile,t,"ff",curfile,t.jump)
	makeGFlyModeKey(profile,t,"gff",curfile,t.jump)
	filename=t.pathfj..t.space..t.X..t.W..t.S..t.A..t.D.."t.txt"
	tglfile = cbOpen(filename,"w")
	t.ini = "+ "
	makeBaseModeKey(profile,t,"fr",tglfile,t.jump,SoD.JumpModeKey)
	tglfile:close()
	curfile:write(SoD.JumpModeKey..' "'..t.turn..actPower(nil,true,t.cjmp)..'$$bindloadfilesilent'..filename..'"\n')
	--makeBaseModeKey(profile,t,"fr",curfile,t.speed,SoD.RunModeKey)
	if t.canss>0 then
		filename=t.pathfj..t.space..t.X..t.W..t.S..t.A..t.D.."s.txt"
		tglfile = cbOpen(filename,"w")
		t.ini = "+ "
		makeSpeedModeKey(profile,t,"fs",tglfile,t.jump)
		tglfile:close()
		curfile:write(SoD.RunModeKey..' "'..t.turn..jup..actPower(nil,true,t.cjmp)..'$$bindloadfilesilent'..filename..'"\n')
	end
	
	curfile:write(SoD.AutoRunKey.." nop\n")
	
	if t.tkeys==0 then t.toggleoff=actPower(nil,true,t.cjmp,t.jump) else t.toggleoff="" end
	if t.jkeys>0 then jup="$$up 1" else jup="$$up 0" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.toggleoff..jup..t.dow..t.forw..t.bac..t.lef..t.rig..t.blj..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
	
	curfile:close()
end

function makeFlightFile(profile,t)
	local bindload, filename, curfile
	local SoD = profile.SoD
--Blast Off Binds
	filename=t.pathbo..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	local fly,hov
	if t.canhov == 1 then
		hov=t.hover
	else
		hov=t.fly
	end
	if t.canfly == 1 then
		fly=t.fly
	else
		fly=t.hover
	end

	curfile:write(profile.ResetKey..' "'.."up 1$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,hov).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.patha.."000000.txt"..'"\n')

	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..actPower(nil,true,nil,t.hover,t.fly)..'$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
	end

	if t.tkeys==0 then t.toggleon=t.mlon..actPower(nil,true,fly) else t.toggleon="" end
		
	bindload=t.blbo..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blbo..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn.."$$up 1"..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blbo..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn.."$$up 1"..t.dow..t.forx..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn.."$$up 1"..t.dow..t.forx..t.bac..t.rig..t.lef..t.toggleon..bindload..'"\n')
	end
		
	bindload=t.blbo..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bacx..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blbo..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bac..t.lefx..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blbo..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bac..t.lef..t.rigx..t.toggleon..bindload..'"\n')
		
	if t.tkeys==0 then t.toggleon=actPower(nil,true,hov) else t.toggleon="" end
	bindload=t.bla..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.FlyModeKey..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.mlon..t.toggleon..bindload..'"\n')
		
	if t.canss>0 then curfile:write(SoD.RunModeKey.." nop\n") end
	if t.canjmp>0 then curfile:write(SoD.JumpModeKey.." nop\n") end
	
	curfile:write(SoD.AutoRunKey.." nop\n")
	curfile:write(SoD.FollowKey.." nop\n")
		
	curfile:close()
--Set Down Binds
	filename=t.pathsd..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
		
	curfile:write(profile.ResetKey..' "'.."up 0$$down 1$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,hov).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.patha.."000000.txt"..'"\n')

	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.hover,t.fly).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
--	if tkeys==0 then toggleon=mlon..sprint..hover..hover..fly..fly else toggleon="" end
--	if tkeys==0 then toggleon="" else toggleon="" end
	t.toggleon=""
		
	bindload=t.blsd..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blsd..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn.."$$down 1"..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blsd..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn.."$$down 1"..t.dow..t.forx..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn.."$$down 1"..t.dow..t.forx..t.bac..t.rig..t.lef..t.toggleon..bindload..'"\n')
	end
		
	bindload=t.blsd..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bacx..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blsd..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bac..t.lefx..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blsd..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bac..t.lef..t.rigx..t.toggleon..bindload..'"\n')
		
	--if t.horizkeys==0 then t.toggleon=t.sprint else toggleon=sprint..speed end
	--bindload=t.bl..t.space..t.X..t.W..t.S..A..D..".txt"
	--curfile:write(SoD.RunModeKey..' "'..turn..up..dow..forw..bac..lef..rig..mlon..hover..fly..flyx..toggleon..'$$'..detailhi..runcamdist..bindload..'"\n')
	t.ini = "+ "
	makeBaseModeKey(profile,t,"r",curfile,{hov,fly},SoD.FlyModeKey)

	--if not (SoD.FlyModeKey==SoD.RunModeKey) then curfile:write(SoD.FlyModeKey.." nop\n") end
	curfile:write(SoD.AutoRunKey.." nop\n")
	curfile:write(SoD.FollowKey.." nop\n")
		
	curfile:close()
--FLY Binds
	filename=t.patha..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
		
	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,hov).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.patha.."000000.txt"..'"\n')
		
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.hover,t.fly).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
	if t.tkeys==0 then t.ml = t.mlon t.toggleon=fly else t.toggleon=nil end
		
	if t.tkeys == 1 and t.space == 1 then t.ml = t.mloff t.toggleon=hov end
	bindload=t.bla..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow..t.forw..t.bac..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')

	if t.tkeys==0 then t.ml = t.mlon t.toggleon=fly else t.toggleon=nil end
	
	if t.tkeys == 1 and t.X == 1 then t.ml = t.mloff t.toggleon=hov end
	bindload=t.bla..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx..t.forw..t.bac..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')

	if t.tkeys==0 then t.ml = t.mlon t.toggleon=fly else t.toggleon=nil end
	
	if t.tkeys == 1 and t.W == 1 then t.ml = t.mloff t.toggleon=hov end
	bindload=t.bla..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn..t.up..t.dow..t.forx..t.bac..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.up..t.dow..t.forx..t.bac..t.rig..t.lef..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')
	end

	if t.tkeys==0 then t.ml = t.mlon t.toggleon=fly else t.toggleon=nil end
	
	if t.tkeys == 1 and t.S == 1 then t.ml = t.mloff t.toggleon=hov end
	bindload=t.bla..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn..t.up..t.dow..t.forw..t.bacx..t.lef..t.rig..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')

	if t.tkeys==0 then t.ml = t.mlon t.toggleon=fly else t.toggleon=nil end
	
	if t.tkeys == 1 and t.A == 1 then t.ml = t.mloff t.toggleon=hov end
	bindload=t.bla..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lefx..t.rig..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')

	if t.tkeys==0 then t.ml = t.mlon t.toggleon=fly else t.toggleon=nil end
	
	if t.tkeys == 1 and t.D == 1 then t.ml = t.mloff t.toggleon=hov end
	bindload=t.bla..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lef..t.rigx..t.ml..actPower(nil,true,t.toggleon)..bindload..'"\n')
		
	--if not (SoD.FlyModeKey==SoD.RunModeKey) then
	--	if tkeys>0 then toggleon=fly..fly else toggleon="" end
	--	curfile:write(SoD.FlyModeKey..' "'..string.sub(hover,3,string.len(hover))..hover..toggleon..up..dow..forw..bac..lef..rig..bla..spc..X..W..S..A..D..".txt"..'"\n')
	--end
	makeGFlyModeKey(profile,t,"gbo",curfile,{hov,fly})
	makeSpeedModeKey(profile,t,"s",curfile,{hov,fly})
	makeJumpModeKey(profile,t,"j",curfile,{hov,fly},t.patha)
		
	bindload=t.blsd..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.FlyModeKey..' "'..t.turn.."$$down 1"..actPower(nil,true,fly)..t.detailhi..t.runcamdist..bindload..'"\n')
		
	bindload=t.blaf..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "'.."forward 1$$backward 0"..t.up..t.dow..t.lef..t.rig..t.mlon..actPower(nil,true,fly)..bindload..'"\n')
		
	if t.tkeys==0 then t.toggleon=actPower(nil,true,fly) else t.toggleon="" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.toggleon..t.blff..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		
	curfile:close()
--'AutoFly Binds
	filename=t.pathaf..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
		
	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 1$$backward 0$$left 0$$right 0"..actPower(nil,true,fly).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.patha.."000000.txt"..'"\n')
		
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.hover,t.fly).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
	bindload=t.blaf..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow.."$$backward 0"..t.lef..t.rig..t.mlon..bindload..'"\n')
		
	bindload=t.blaf..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx.."$$backward 0"..t.lef..t.rig..t.mlon..bindload..'"\n')
		
	if t.W == 1 then
		t.toggleon="$$backward 0"
		bindload=t.blaf..t.space..t.X.."0"..t.S..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 1$$backward 0"
		bindload=t.bla..t.space..t.X.."1"..t.S..t.A..t.D..".txt"
	end
	curfile:write(SoD.Forward..' "'..t.turn..t.toggleon..t.up..t.dow..t.lef..t.rig..t.mlon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.toggleon..t.up..t.dow..t.rig..t.lef..t.mlon..bindload..'"\n')
	end
		
	if t.S == 1 then
		t.toggleon="$$backward 0"
		bindload=t.blaf..t.space..t.X..t.W.."0"..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 0$$backward 1"
		bindload=t.bla..t.space..t.X..t.W.."1"..t.A..t.D..".txt"
	end
	curfile:write(SoD.Back..' "'..t.turn..t.toggleon..t.up..t.dowx..t.lef..t.rig..t.mlon..bindload..'"\n')
		
	bindload=t.blaf..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..t.up..t.dow.."$$backward 0"..t.lefx..t.rig..t.mlon..bindload..'"\n')
		
	bindload=t.blaf..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..t.up..t.dow.."$$backward 0"..t.lef..t.rigx..t.mlon..bindload..'"\n')
		
	makeGFlyModeKey(profile,t,"gaf",curfile,{hov,fly})
	makeJumpModeKey(profile,t,"aj",curfile,{hov,fly},t.pathaf)
	makeSpeedModeKey(profile,t,"as",curfile,{hov,flyoff})
	makeBaseModeKey(profile,t,"gr",curfile,{hov,fly},SoD.FlyModeKey)
	
	if t.tkeys>0 then t.toggleon=t.mlon..actPower(nil,true,fly) else t.toggleon=t.mloff..actPower(nil,true,hov) end
	bindload=t.bla..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "'..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	curfile:write(SoD.FollowKey.." nop\n")
		
	curfile:close()
--'FollowFly Binds
	filename=t.pathff..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
			
	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,fly).."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.patha.."000000.txt"..'"\n')
	
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..actPower(nil,true,nil,t.hover,t.fly).."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
	if t.space == 1 then bindload=t.blff.."0"..t.X..t.W..t.S..t.A..t.D..".txt" else bindload=t.bla.."1"..t.X..t.W..t.S..t.A..t.D..".txt" end
	if t.space == 1 then t.toggleon="" else t.toggleon=t.upx..t.dow..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Up..' "'..t.toggleon..bindload..'"\n')
		
	if t.X == 1 then bindload=t.blff..t.space.."0"..t.W..t.S..t.A..t.D..".txt" else bindload=t.bla..t.space.."1"..t.W..t.S..t.A..t.D..".txt" end
	if t.X == 1 then t.toggleon="" else t.toggleon=t.up..t.dowx..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Down..' "'..t.toggleon..bindload..'"\n')
		
	if t.W == 1 then bindload=t.blff..t.space..t.X.."0"..t.S..t.A..t.D..".txt" else bindload=t.bla..t.space..t.X.."1"..t.S..t.A..t.D..".txt" end
	if t.W == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.lef..t.rig end
	curfile:write(SoD.Forward..' "'..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		if t.W == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.rig..t.lef end
		curfile:write('mousechord "'..t.toggleon..bindload..'"\n')
	end
		
	if t.S == 1 then bindload=t.blff..t.space..t.X..t.W.."0"..t.A..t.D..".txt" else bindload=t.bla..t.space..t.X..t.W.."1"..t.A..t.D..".txt" end
	if t.S == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bacx..t.lef..t.rig end
	curfile:write(SoD.Back..' "'..t.toggleon..bindload..'"\n')
		
	if t.A == 1 then bindload=t.blff..t.space..t.X..t.W..t.S.."0"..t.D..".txt" else bindload=t.bla..t.space..t.X..t.W..t.S.."1"..t.D..".txt" end
	if t.A == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lefx..t.rig end
	curfile:write(SoD.Left..' "'..t.toggleon..bindload..'"\n')
		
	if t.D == 1 then bindload=t.blff..t.space..t.X..t.W..t.S..t.A.."0"..".txt" else bindload=t.bla..t.space..t.X..t.W..t.S..t.A.."1"..".txt" end
	if t.D == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lef..t.rigx end
	curfile:write(SoD.Right..' "'..t.toggleon..bindload..'"\n')
		
	makeGFlyModeKey(profile,t,"gff",curfile,{hov,fly})
	makeBaseModeKey(profile,t,"fr",curfile,{hov,fly},SoD.FlyModeKey)
	makeJumpModeKey(profile,t,"fj",curfile,{hov,fly},t.pathff)
	makeSpeedModeKey(profile,t,"fs",curfile,{hov,fly})
		
	curfile:write(SoD.AutoRunKey.." nop\n")
		
	if t.tkeys==0 then t.toggleoff=actPower(nil,true,hov) else t.toggleoff="" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.toggleoff..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.bla..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		
	curfile:close()
end

function makeGFlightFile(profile,t)
	local bindload, filename, curfile
	local SoD = profile.SoD
--Blast Off Binds
	filename=t.pathgbo..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")

	curfile:write(profile.ResetKey..' "'.."up 1$$down 0$$forward 0$$backward 0$$left 0$$right 0"..t.on..t.gfly.."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.pathga.."000000.txt"..'"\n')

	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "tell $name, Changing to Normal Movement$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$bind_load_file_silent '..t.basepath..'\\reset.txt"\n')
	end

	if t.tkeys==0 then t.toggleon=t.mlon..t.on..t.gfly else t.toggleon=t.on..t.gfly end
		
	bindload=t.blgbo..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgbo..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn.."$$up 1"..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgbo..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn.."$$up 1"..t.dow..t.forx..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn.."$$up 1"..t.dow..t.forx..t.bac..t.rig..t.lef..t.toggleon..bindload..'"\n')
	end
		
	bindload=t.blgbo..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bacx..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgbo..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bac..t.lefx..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgbo..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$up 1"..t.dow..t.forw..t.bac..t.lef..t.rigx..t.toggleon..bindload..'"\n')
		
	--if t.tkeys==0 then t.toggleon=t.gfly..t.gfly else t.toggleon="" end
	bindload=t.blga..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.GFlyModeKey..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.mlon..t.on.t.gfly..bindload..'"\n')
		
	if t.canss>0 then curfile:write(SoD.RunModeKey.." nop\n") end
	if t.canjmp>0 then curfile:write(SoD.JumpModeKey.." nop\n") end
	
	curfile:write(SoD.AutoRunKey.." nop\n")
	curfile:write(SoD.FollowKey.." nop\n")
		
	curfile:close()
--Set Down Binds
	filename=t.pathgsd..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
		
	curfile:write(profile.ResetKey..' "'.."up 0$$down 1$$forward 0$$backward 0$$left 0$$right 0"..t.on..t.gfly.."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.pathga.."000000.txt"..'"\n')

	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0".."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
--	if tkeys==0 then toggleon=mlon..sprint..hover..hover..fly..fly else toggleon="" end
--	if tkeys==0 then toggleon="" else toggleon="" end
	t.toggleon=t.on..t.gfly
		
	bindload=t.blgsd..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgsd..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn.."$$down 1"..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgsd..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn.."$$down 1"..t.dow..t.forx..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn.."$$down 1"..t.dow..t.forx..t.bac..t.rig..t.lef..t.toggleon..bindload..'"\n')
	end
		
	bindload=t.blgsd..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bacx..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgsd..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bac..t.lefx..t.rig..t.toggleon..bindload..'"\n')
		
	bindload=t.blgsd..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn.."$$down 1"..t.dow..t.forw..t.bac..t.lef..t.rigx..t.toggleon..bindload..'"\n')
		
	--if t.horizkeys==0 then t.toggleon=t.sprint else toggleon=sprint..speed end
	--bindload=t.bl..t.space..t.X..t.W..t.S..A..D..".txt"
	--curfile:write(SoD.RunModeKey..' "'..turn..up..dow..forw..bac..lef..rig..mlon..hover..fly..flyx..toggleon..'$$'..detailhi..runcamdist..bindload..'"\n')
	makeBaseModeKey(profile,t,"r",curfile,"$$+ "..t.off..t.gfly,SoD.GFlyModeKey)

	--if not (SoD.FlyModeKey==SoD.RunModeKey) then curfile:write(SoD.FlyModeKey.." nop\n") end
	curfile:write(SoD.AutoRunKey.." nop\n")
	curfile:write(SoD.FollowKey.." nop\n")
		
	curfile:close()
--FLY Binds
	filename=t.pathga..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
		
	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..t.on..t.gfly.."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.pathga.."000000.txt"..'"\n')
		
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0".."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
	if t.tkeys==0 then t.toggleon=t.mlon..t.on..t.gfly else t.toggleon=t.on..t.gfly end
		
	if t.tkeys == 1 and t.space == 1 then t.toggleoff=t.mloff else t.toggleoff="" end
	bindload=t.blga..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
		
	if t.tkeys == 1 and t.X == 1 then t.toggleoff=t.mloff else t.toggleoff="" end
	bindload=t.blga..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx..t.forw..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
		
	if t.tkeys == 1 and t.W == 1 then t.toggleoff=t.mloff else t.toggleoff="" end
	bindload=t.blga..t.space..t.X..(1-t.W)..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Forward..' "'..t.turn..t.up..t.dow..t.forx..t.bac..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.up..t.dow..t.forx..t.bac..t.rig..t.lef..t.toggleon..t.toggleoff..bindload..'"\n')
	end
		
	if t.tkeys == 1 and t.S == 1 then t.toggleoff=t.mloff else t.toggleoff="" end
	bindload=t.blga..t.space..t.X..t.W..(1-t.S)..t.A..t.D..".txt"
	curfile:write(SoD.Back..' "'..t.turn..t.up..t.dow..t.forw..t.bacx..t.lef..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
		
	if t.tkeys == 1 and t.A == 1 then t.toggleoff=t.mloff else t.toggleoff="" end
	bindload=t.blga..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lefx..t.rig..t.toggleon..t.toggleoff..bindload..'"\n')
		
	if t.tkeys == 1 and t.D == 1 then t.toggleoff=t.mloff else t.toggleoff="" end
	bindload=t.blga..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..t.up..t.dow..t.forw..t.bac..t.lef..t.rigx..t.toggleon..t.toggleoff..bindload..'"\n')
		
	--if not (SoD.FlyModeKey==SoD.RunModeKey) then
	--	if tkeys>0 then toggleon=fly..fly else toggleon="" end
	--	curfile:write(SoD.FlyModeKey..' "'..string.sub(hover,3,string.len(hover))..hover..toggleon..up..dow..forw..bac..lef..rig..bla..spc..X..W..S..A..D..".txt"..'"\n')
	--end
	makeFlyModeKey(profile,t,"a",curfile,t.off..t.gfly)
	makeSpeedModeKey(profile,t,"s",curfile,t.off..t.gfly)
	makeJumpModeKey(profile,t,"j",curfile,t.off..t.gfly,t.pathga)
		
	bindload=t.blgsd..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.GFlyModeKey..' "'..t.turn.."$$down 1"..t.on..t.gfly..t.detailhi..t.runcamdist..bindload..'"\n')
		
	bindload=t.blgaf..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "'.."forward 1$$backward 0"..t.up..t.dow..t.lef..t.rig..t.mlon..t.on..t.gfly..bindload..'"\n')
		
	if t.tkeys==0 then t.toggleon=t.on..t.gfly else t.toggleon="" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.toggleon..t.blgff..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		
	curfile:close()
--'AutoFly Binds
	filename=t.pathgaf..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
		
	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 1$$backward 0$$left 0$$right 0"..t.on..t.gfly.."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.pathga.."000000.txt"..'"\n')
		
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0".."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
	bindload=t.blgaf..(1-t.space)..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Up..' "'..t.turn..t.upx..t.dow.."$$backward 0"..t.lef..t.rig..t.mlon..t.on..t.gfly..bindload..'"\n')
		
	bindload=t.blgaf..t.space..(1-t.X)..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.Down..' "'..t.turn..t.up..t.dowx.."$$backward 0"..t.lef..t.rig..t.mlon..t.on..t.gfly..bindload..'"\n')
		
	if t.W == 1 then
		t.toggleon="$$backward 0"
		bindload=t.blgaf..t.space..t.X.."0"..t.S..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 1$$backward 0"
		bindload=t.blga..t.space..t.X.."1"..t.S..t.A..t.D..".txt"
	end
	curfile:write(SoD.Forward..' "'..t.turn..t.toggleon..t.up..t.dow..t.lef..t.rig..t.mlon..t.on..t.gfly..bindload..'"\n')
	if SoD.MouseChord then
		curfile:write('mousechord "'..t.turn..t.toggleon..t.up..t.dow..t.rig..t.lef..t.mlon..t.on..t.gfly..bindload..'"\n')
	end
		
	if t.S == 1 then
		t.toggleon="$$backward 0"
		bindload=t.blgaf..t.space..t.X..t.W.."0"..t.A..t.D..".txt"
	else
		t.toggleon="$$forward 0$$backward 1"
		bindload=t.blga..t.space..t.X..t.W.."1"..t.A..t.D..".txt"
	end
	curfile:write(SoD.Back..' "'..t.turn..t.toggleon..t.up..t.dowx..t.lef..t.rig..t.mlon..t.on..t.gfly..bindload..'"\n')
		
	bindload=t.blgaf..t.space..t.X..t.W..t.S..(1-t.A)..t.D..".txt"
	curfile:write(SoD.Left..' "'..t.turn..t.up..t.dow.."$$backward 0"..t.lefx..t.rig..t.mlon..t.on..t.gfly..bindload..'"\n')
		
	bindload=t.blgaf..t.space..t.X..t.W..t.S..t.A..(1-t.D)..".txt"
	curfile:write(SoD.Right..' "'..t.turn..t.up..t.dow.."$$backward 0"..t.lef..t.rigx..t.mlon..t.on..t.gfly..bindload..'"\n')
		
	makeFlyModeKey(profile,t,"af",curfile,t.off..t.gfly.."$$backward 0")
	makeJumpModeKey(profile,t,"aj",curfile,t.off..t.gfly.."$$backward 0",t.pathgaf)
	makeSpeedModeKey(profile,t,"as",curfile,t.off..t.gfly.."$$backward 0")
	makeBaseModeKey(profile,t,"gr",curfile,t.off..t.gfly.."$$backward 0",SoD.GFlyModeKey)
	
	if t.tkeys>0 then t.toggleon=t.mlon..t.on..t.gfly else t.toggleon=t.mloff..t.on..t.gfly end
	bindload=t.blga..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile:write(SoD.AutoRunKey..' "'..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.toggleon..bindload..'"\n')
		
	curfile:write(SoD.FollowKey.." nop\n")
		
	curfile:close()
--'FollowFly Binds
	filename=t.pathgff..t.space..t.X..t.W..t.S..t.A..t.D..".txt"
	curfile = cbOpen(filename,"w")
			
	curfile:write(profile.ResetKey..' "'.."up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0"..t.on..t.gfly.."$$tell $name, SoD Binds Reset$$bind_load_file_silent "..t.patha.."000000.txt"..'"\n')
	
	if t.tkeys==0 then
		curfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to Normal Movement".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0".."$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
	end
		
	if t.space == 1 then bindload=t.blgff.."0"..t.X..t.W..t.S..t.A..t.D..".txt" else bindload=t.blga.."1"..t.X..t.W..t.S..t.A..t.D..".txt" end
	if t.space == 1 then t.toggleon="" else t.toggleon=t.upx..t.dow..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Up..' "'..t.toggleon..bindload..'"\n')
		
	if t.X == 1 then bindload=t.blgff..t.space.."0"..t.W..t.S..t.A..t.D..".txt" else bindload=t.blga..t.space.."1"..t.W..t.S..t.A..t.D..".txt" end
	if t.X == 1 then t.toggleon="" else t.toggleon=t.up..t.dowx..t.forw..t.bac..t.lef..t.rig end
	curfile:write(SoD.Down..' "'..t.toggleon..bindload..'"\n')
		
	if t.W == 1 then bindload=t.blgff..t.space..t.X.."0"..t.S..t.A..t.D..".txt" else bindload=t.blga..t.space..t.X.."1"..t.S..t.A..t.D..".txt" end
	if t.W == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.lef..t.rig end
	curfile:write(SoD.Forward..' "'..t.toggleon..bindload..'"\n')
	if SoD.MouseChord then
		if t.W == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forx..t.bac..t.rig..t.lef end
		curfile:write('mousechord "'..t.toggleon..bindload..'"\n')
	end
		
	if t.S == 1 then bindload=t.blgff..t.space..t.X..t.W.."0"..t.A..t.D..".txt" else bindload=t.blga..t.space..t.X..t.W.."1"..t.A..t.D..".txt" end
	if t.S == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bacx..t.lef..t.rig end
	curfile:write(SoD.Back..' "'..t.toggleon..bindload..'"\n')
		
	if t.A == 1 then bindload=t.blgff..t.space..t.X..t.W..t.S.."0"..t.D..".txt" else bindload=t.blga..t.space..t.X..t.W..t.S.."1"..t.D..".txt" end
	if t.A == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lefx..t.rig end
	curfile:write(SoD.Left..' "'..t.toggleon..bindload..'"\n')
		
	if t.D == 1 then bindload=t.blgff..t.space..t.X..t.W..t.S..t.A.."0"..".txt" else bindload=t.blga..t.space..t.X..t.W..t.S..t.A.."1"..".txt" end
	if t.D == 1 then t.toggleon="" else t.toggleon=t.up..t.dow..t.forw..t.bac..t.lef..t.rigx end
	curfile:write(SoD.Right..' "'..t.toggleon..bindload..'"\n')
		
	makeFlyModeKey(profile,t,"ff",curfile,t.off..t.gfly)
	makeBaseModeKey(profile,t,"fr",curfile,t.off..t.gfly,SoD.GFlyModeKey)
	makeJumpModeKey(profile,t,"fj",curfile,t.off..t.gfly,t.pathgff)
	makeSpeedModeKey(profile,t,"fs",curfile,t.off..t.gfly)
		
	curfile:write(SoD.AutoRunKey.." nop\n")
		
	--if t.tkeys==0 then t.toggleoff=t.gfly..t.gfly else t.toggleoff="" end
	curfile:write(SoD.FollowKey..' "'.."follow"..t.up..t.dow..t.forw..t.bac..t.lef..t.rig..t.blga..t.space..t.X..t.W..t.S..t.A..t.D..".txt"..'"\n')
		
	curfile:close()
end

function module.makebind(profile)
	local resetfile = profile.resetfile
	local SoD = profile.SoD
	local t = {}
	--resetfile:write(petselect.sel5 .. ' "petselect 5"\n')
	t.hover = ""
	t.fly = ""
	t.flyx = ""
	t.jump = ""
	t.cjmp = ""
	t.canhov = 0
	t.canfly = 0
	t.cancj = 0
	t.canjmp = 0
	t.on = "$$powexectoggleon "
	--t.on = "$$powexecname "
	t.off = "$$powexectoggleoff "
	if SoD.Jump.CJ and SoD.Jump.SJ == nil then
		t.cancj = 1
		t.canjmp = 0
		t.jump = "Combat Jumping"
	end
	if SoD.Jump.CJ == nil and SoD.Jump.SJ then
		t.cancj = 0
		t.canjmp = 1
		t.jump = "Super Jump"
	end
	if SoD.Jump.CJ and SoD.Jump.SJ then
		t.cancj = 1
		t.canjmp = 1
		t.cjmp = "Combat Jumping"
		t.jump = "Super Jump"
	end
	if profile.archetype == "Peacebringer" then
		if SoD.Fly.Hover then
			t.canhov = 1
			t.canfly = 1
			t.hover = "Combat Flight"
			t.fly = "Energy Flight"
			t.flyx = "Energy Flight"
		else
			t.canhov = 0
			t.canfly = 1
			t.flyx = "Energy Flight"
		end
	elseif not (profile.archetype == "Warshade") then
		if SoD.Fly.Hover and SoD.Fly.Fly == nil then
			t.canhov = 1
			t.canfly = 0
			t.flyx = "Hover"
		end
		if SoD.Fly.Hover == nil and SoD.Fly.Fly then
			t.canhov = 0
			t.canfly = 1
			t.flyx = "Fly"
		end
		if SoD.Fly.Hover and SoD.Fly.Fly then
			t.canhov = 1
			t.canfly = 1
			t.hover = "Hover"
			t.fly = "Fly"
			t.flyx = "Fly"
		end
	end
	if SoD.Fly.GFly then
		t.cangfly = 1
		t.gfly = "Group Fly"
	else
		t.cangfly = 0
	end
	t.sprint = ""
	t.speed = ""
	if SoD.Run.PrimaryNumber == 1 then
		t.sprint = SoD.Run.Secondary
		t.speed = SoD.Run.Secondary
		t.canss = 0
	else
		t.sprint = SoD.Run.Secondary
		t.speed = SoD.Run.Primary
		t.canss = 1
	end
	if SoD.Unqueue then t.unqueue = "$$powexecunqueue" else t.unqueue = "" end
	t.unqueue = ""
	if SoD.AutoMouseLook then
		t.mlon = "$$mouse_look 1"
		t.mloff = "$$mouse_look 0"
	else
		t.mlon = ""
		t.mloff = ""
	end
	t.runcamdist = ""
	t.flycamdist = ""
	if SoD.Run.UseCamdist then
		t.runcamdist = "$$camdist "..SoD.Run.Camdist
	end
	if SoD.Fly.UseCamdist then
		t.flycamdist = "$$camdist "..SoD.Fly.Camdist
	end
	t.detailhi = ""
	t.detaillo = ""
	if SoD.Detail and SoD.Detail.Enable then
		t.detailhi = "$$vis_scale "..SoD.Detail.NormalAmt.."$$shadowvol 0$$ss 0"
		t.detaillo = "$$vis_scale "..SoD.Detail.MovingAmt.."$$shadowvol 0$$ss 0"
	end
	
	t.basepath = profile.base

	t.subdirg=t.basepath.."\\R"
	t.subdira=t.basepath.."\\F"
	t.subdirj=t.basepath.."\\J"
	t.subdirs=t.basepath.."\\S"
	t.subdirga=t.basepath.."\\GF"
	t.subdirar=t.basepath.."\\AR"
	t.subdiraf=t.basepath.."\\AF"
	t.subdiraj=t.basepath.."\\AJ"
	t.subdiras=t.basepath.."\\AS"
	t.subdirgaf=t.basepath.."\\GAF"
	t.subdirfr=t.basepath.."\\FR"
	t.subdirff=t.basepath.."\\FF"
	t.subdirfj=t.basepath.."\\FJ"
	t.subdirfs=t.basepath.."\\FS"
	t.subdirgff=t.basepath.."\\GFF"
	-- Special Modes used for Flight: Blastoff mode and setdown mode
	t.subdirbo=t.basepath.."\\BO"
	t.subdirsd=t.basepath.."\\SD"
	t.subdirgbo=t.basepath.."\\GBO"
	t.subdirgsd=t.basepath.."\\GSD"
	--local turn="+zoomin$$-zoomin"  --a non functioning bind used only to activate the keydown/keyup functions of +commands
	t.turn="+ "  --a non functioning bind used only to activate the keydown/keyup functions of +commands
	
	t.path=t.subdirg.."\\R" --ground subfolder and base filename.  Keep it shortish
	t.bl="$$bind_load_file_silent "..t.path
	t.patha=t.subdira.."\\F" --air subfolder and base filename
	t.bla="$$bind_load_file_silent "..t.patha
	t.pathj=t.subdirj.."\\J"
	t.blj="$$bind_load_file_silent "..t.pathj
	t.paths=t.subdirs.."\\S"
	t.bls="$$bind_load_file_silent "..t.paths
	t.pathga=t.subdirga.."\\GF" --air subfolder and base filename
	t.blga="$$bind_load_file_silent "..t.pathga
	t.pathgr=t.subdirar.."\\AR"  --ground autorun subfolder and base filename
	t.blgr="$$bind_load_file_silent "..t.pathgr
	t.pathaf=t.subdiraf.."\\AF"  --air autorun subfolder and base filename
	t.blaf="$$bind_load_file_silent "..t.pathaf
	t.pathaj=t.subdiraj.."\\AJ"
	t.blaj="$$bind_load_file_silent "..t.pathaj
	t.pathas=t.subdiras.."\\AS"
	t.blas="$$bind_load_file_silent "..t.pathas
	t.pathgaf=t.subdirgaf.."\\GAF"  --air autorun subfolder and base filename
	t.blgaf="$$bind_load_file_silent "..t.pathgaf
	t.pathfr=t.subdirfr.."\\FR"  --Follow Run subfolder and base filename
	t.blfr="$$bind_load_file_silent "..t.pathfr
	t.pathff=t.subdirff.."\\FF"  --Follow Fly subfolder and base filename
	t.blff="$$bind_load_file_silent "..t.pathff
	t.pathfj=t.subdirfj.."\\FJ"
	t.blfj="$$bind_load_file_silent "..t.pathfj
	t.pathfs=t.subdirfs.."\\FS"
	t.blfs="$$bind_load_file_silent "..t.pathfs
	t.pathgff=t.subdirgff.."\\GFF"  --Follow Fly subfolder and base filename
	t.blgff="$$bind_load_file_silent "..t.pathgff
	t.pathbo=t.subdirbo.."\\BO"  --Blastoff Fly subfolder and base filename
	t.blbo="$$bind_load_file_silent "..t.pathbo
	t.pathsd=t.subdirsd.."\\SD"  -- SetDown Fly Subfolder and base filename
	t.blsd="$$bind_load_file_silent "..t.pathsd
	t.pathgbo=t.subdirgbo.."\\GBO"  --Blastoff Fly subfolder and base filename
	t.blgbo="$$bind_load_file_silent "..t.pathgbo
	t.pathgsd=t.subdirgsd.."\\GSD"  -- SetDown Fly Subfolder and base filename
	t.blgsd="$$bind_load_file_silent "..t.pathgsd

	os.execute("mkdir "..t.subdirg)
	os.execute("mkdir "..t.subdirar)
	os.execute("mkdir "..t.subdirfr)

	if t.canhov+t.canfly>0 then
		os.execute("mkdir "..t.subdira)
		os.execute("mkdir "..t.subdiraf)
		os.execute("mkdir "..t.subdirff)
		os.execute("mkdir "..t.subdirbo)
		os.execute("mkdir "..t.subdirsd)
	end

	if t.canjmp>0 then
		os.execute("mkdir "..t.subdirj)
		os.execute("mkdir "..t.subdiraj)
		os.execute("mkdir "..t.subdirfj)
	end

	if t.canss>0 then
		os.execute("mkdir "..t.subdirs)
		os.execute("mkdir "..t.subdiras)
		os.execute("mkdir "..t.subdirfs)
	end
	
	if t.cangfly>0 then
		os.execute("mkdir "..t.subdirga)
		os.execute("mkdir "..t.subdirgaf)
		os.execute("mkdir "..t.subdirgff)
		os.execute("mkdir "..t.subdirgbo)
		os.execute("mkdir "..t.subdirgsd)
	end

	for space = 0, 1 do
		t.space=space
		if space == 1 then t.up="$$up 1" else t.up="$$up 0" end --up is direction you should be going already in this file
		if space == 1 then t.upx="$$up 0" else t.upx="$$up 1" end --and upx for direction you should change to if you press/release this key
		for X = 0, 1 do
			t.X=X
			if X == 1 then t.dow="$$down 1" else t.dow="$$down 0" end
			if X == 1 then t.dowx="$$down 0" else t.dowx="$$down 1" end
			for W = 0, 1 do
				t.W=W
				if W == 1 then t.forw="$$forward 1" else t.forw="$$forward 0" end
				if W == 1 then t.forx="$$forward 0" else t.forx="$$forward 1" end
				for S = 0, 1 do
					t.S=S
					if S == 1 then t.bac="$$backward 1" else t.bac="$$backward 0" end
					if S == 1 then t.bacx="$$backward 0" else t.bacx="$$backward 1" end
					for A = 0, 1 do
						t.A=A
						if A == 1 then t.lef="$$left 1" else t.lef="$$left 0" end
						if A == 1 then t.lefx="$$left 0" else t.lefx="$$left 1" end
						for D = 0, 1 do
							t.D=D
							if D == 1 then t.rig="$$right 1" else t.rig="$$right 0" end
							if D == 1 then t.rigx="$$right 0" else t.rigx="$$right 1" end

							t.tkeys=space+X+W+S+A+D	--total number of keys down
							t.horizkeys=W+S+A+D	--total # of horizontal move keys.	So Sprint isn't turned on when jumping
							t.vertkeys=space+X
							makeBaseFile(profile,t)
							if t.canss>0 then
								makeSpeedFile(profile,t)
							end
							if t.canjmp>0 then
								makeJumpFile(profile,t)
							end
							if t.canhov+t.canfly>0 then
								makeFlightFile(profile,t)
							end
							if t.cangfly>0 then
								makeGFlightFile(profile,t)
							end
						end
					end
				end
			end
		end
	end
	
	local dwarfTPPower, normalTPPower, windowhide, windowshow, teamTPPower
	if profile.archetype == "Warshade" then
		dwarfTPPower = "powexecname Black Dwarf Step"
		normalTPPower = "powexecname Shadow Step"
	elseif profile.archetype == "Peacebringer" then
		dwarfTPPower = "powexecname White Dwarf Step"
	else
		normalTPPower = "powexecname Teleport"
		teamTPPower = "powexecname Team Teleport"
	end
	local windowhide = "$$hide health$$hide chat$$hide target$$hide tray"
	local windowshow = "$$show health$$show chat$$show target$$show tray"
	-- kheldian form support -- create the Nova and Dwarf form support files if enabled.
	if SoD.Nova and SoD.Nova.Enable then
		resetfile:write(SoD.Nova.ModeKey..' "tell $name, Changing to '..SoD.Nova.Nova..' Form$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..t.on..SoD.Nova.Nova.."$$goto_tray "..SoD.Nova.PowerTray.."$$bind_load_file_silent "..t.basepath.."\\nova.txt"..'"\n')
		local novafile = cbOpen(t.basepath.."\\nova.txt","w")
		if SoD.Dwarf and SoD.Dwarf.Enable then
			novafile:write(SoD.Dwarf.ModeKey..' "tell $name, Changing to '..SoD.Dwarf.Dwarf..' Form$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0'..t.off..SoD.Nova.Nova..t.on..SoD.Dwarf.Dwarf.."$$goto_tray "..SoD.Dwarf.PowerTray.."$$bind_load_file_silent "..t.basepath.."\\dwarf.txt"..'"\n')
		end
		novafile:write(SoD.Forward..' "'.."+forward"..'"\n')
		if SoD.MouseChord then
			novafile:write('mousechord "'.."+ $$+forward"..'"\n')
		end
		novafile:write(SoD.Left..' "'.."+left"..'"\n')
		novafile:write(SoD.Right..' "'.."+right"..'"\n')
		novafile:write(SoD.Back..' "'.."+backward"..'"\n')
		novafile:write(SoD.Up..' "'.."+up"..'"\n')
		novafile:write(SoD.Down..' "'.."+down"..'"\n')
		novafile:write(SoD.AutoRunKey..' "'.."++forward"..'"\n')
		novafile:write(SoD.FlyModeKey.." nop\n")
		if not (SoD.FlyModeKey==SoD.RunModeKey) then
			novafile:write(SoD.RunModeKey.." nop\n")
		end
		novafile:write(SoD.FollowKey..' "'.."follow"..'"\n')
		novafile:write(SoD.ToggleKey..' "tell $name, Changing to Human Form, Normal Mode$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$powexec_toggle_off '..SoD.Nova.Nova.."$$goto_tray 1$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
		novafile:write(SoD.Nova.ModeKey..' "'.."tell $name, Changing to Human Form, SoD Mode$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$powexec_toggle_off "..SoD.Nova.Nova.."$$goto_tray 1$$bind_load_file_silent "..t.path.."00000.txt"..'"\n')
		novafile:close()
	end
	if SoD.Dwarf and SoD.Dwarf.Enable then
		resetfile:write(SoD.Dwarf.ModeKey..' "tell $name, Changing to '..SoD.Dwarf.Dwarf..' Form$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$powexec_toggle_on '..SoD.Dwarf.Dwarf.."$$goto_tray "..SoD.Dwarf.PowerTray.."$$bind_load_file_silent "..t.basepath.."\\dwarf.txt"..'"\n')
		local dwrffile = cbOpen(t.basepath.."\\dwarf.txt","w")
		if SoD.Nova and SoD.Nova.Enable then
			dwrffile:write(SoD.Nova.ModeKey..' "tell $name, Changing to '..SoD.Nova.Nova..' Form$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$powexec_toggle_off '..SoD.Dwarf.Dwarf..'$$powexec_toggle_on '..SoD.Nova.Nova.."$$goto_tray "..SoD.Nova.PowerTray.."$$bind_load_file_silent "..t.basepath.."\\nova.txt"..'"\n')
		end
		dwrffile:write(SoD.Forward..' "'.."+forward"..'"\n')
		if SoD.MouseChord then
			dwrffile:write('mousechord "'.."+ $$+forward"..'"\n')
		end
		dwrffile:write(SoD.Left..' "'.."+left"..'"\n')
		dwrffile:write(SoD.Right..' "'.."+right"..'"\n')
		dwrffile:write(SoD.Back..' "'.."+backward"..'"\n')
		dwrffile:write(SoD.Up..' "'.."+up"..'"\n')
		dwrffile:write(SoD.Down..' "'.."+down"..'"\n')
		dwrffile:write(SoD.AutoRunKey..' "'.."++forward"..'"\n')
		dwrffile:write(SoD.FlyModeKey.." nop\n")
		if not (SoD.FlyModeKey==SoD.RunModeKey) then
			dwrffile:write(SoD.RunModeKey.." nop\n")
		end
		dwrffile:write(SoD.FollowKey..' "'.."follow"..'"\n')
		if SoD.TP and SoD.TP.Enable then
			dwrffile:write(SoD.TP.ComboKey..' "+ $$'..dwarfTPPower..t.detaillo..t.flycamdist..windowhide..'$$bindloadfilesilent'..t.basepath..'\\dtp\\tp_on1.txt"\n')
			dwrffile:write(SoD.TP.BindKey..' nop\n')
			dwrffile:write(SoD.TP.ResetKey..' "'..string.sub(t.detailhi,3,string.len(t.detailhi))..t.runcamdist..windowshow..'$$bindloadfilesilent'..t.basepath..'\\dtp\\tp_off.txt"\n')
			-- Create tp directory
			cbMakeDirectory(t.basepath..'\\dtp')
			-- Create tp_off file
			local tp_off = cbOpen(t.basepath..'\\dtp\\tp_off.txt',"w")
			tp_off:write(SoD.TP.ComboKey..' "+ $$'..dwarfTPPower..t.detaillo..t.flycamdist..windowhide..'$$bindloadfilesilent'..t.basepath..'\\dtp\\tp_on1.txt"\n')
			tp_off:write(SoD.TP.BindKey..' nop\n')
			tp_off:close()
			local tp_on1 = cbOpen(t.basepath..'\\dtp\\tp_on1.txt',"w")
			tp_on1:write(SoD.TP.ComboKey..' "- $$powexecunqueue'..t.detailhi..t.runcamdist..windowshow..'$$bindloadfilesilent'..t.basepath..'\\dtp\\tp_off.txt"\n')
			tp_on1:write(SoD.TP.BindKey..' "+ $$bindloadfilesilent'..t.basepath..'\\dtp\\tp_on2.txt"\n')
			tp_on1:close()
			local tp_on2 = cbOpen(t.basepath..'\\dtp\\tp_on2.txt',"w")
			tp_on2:write(SoD.TP.BindKey..' "- $$'..dwarfTPPower..'$$bindloadfilesilent'..t.basepath..'\\dtp\\tp_on1.txt"\n')
			tp_on2:close()
		end
		dwrffile:write(SoD.ToggleKey..' "tell $name, Changing to Human Form, Normal Mode$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$powexec_toggle_off '..SoD.Dwarf.Dwarf.."$$goto_tray 1$$bind_load_file_silent "..t.basepath.."\\reset.txt"..'"\n')
		dwrffile:write(SoD.Dwarf.ModeKey..' "'.."tell $name, Changing to Human Form, SoD Mode$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$powexec_toggle_off "..SoD.Dwarf.Dwarf.."$$goto_tray 1$$bind_load_file_silent "..t.path.."00000.txt"..'"\n')
		dwrffile:close()
	end

	--Create Reset File
	--filename=basepath.."\\reset.txt"
	--curfile = cbOpen(filename,"w")
	resetfile:write(SoD.Forward..' "'.."+forward"..'"\n')
	if SoD.MouseChord then
		resetfile:write('mousechord "'.."+ $$+forward"..'"\n')
	end
	resetfile:write(SoD.Left..' "'.."+left"..'"\n')
	resetfile:write(SoD.Right..' "'.."+right"..'"\n')
	resetfile:write(SoD.Back..' "'.."+backward"..'"\n')
	resetfile:write(SoD.Up..' "'.."+up"..'"\n')
	resetfile:write(SoD.Down..' "'.."+down"..'"\n')
	resetfile:write(SoD.AutoRunKey..' "'.."++forward"..'"\n')
	--if t.canhov+t.canfly>0 then
	--	resetfile:write(SoD.FlyModeKey..' "'..string.sub(t.sprint..t.speed,3,string.len(sprint..speed))..fly..hover..'"\n')
	--else
	--	resetfile:write(SoD.FlyModeKey.." nop\n")
	--end
	--if not (SoD.FlyModeKey==SoD.RunModeKey) then
	--	resetfile:write(SoD.RunModeKey..' "'..string.sub(fly,3,string.len(fly))..hover..sprint..speed..'"\n')
	--end
	resetfile:write(SoD.FollowKey..' "'.."follow"..'"\n')
	if SoD.TP and SoD.TP.Enable and not (profile.Archetype == "Peacebringer") then
		resetfile:write(SoD.TP.ComboKey..' "+ $$'..normalTPPower..t.detaillo..t.flycamdist..windowhide..'$$bindloadfilesilent'..t.basepath..'\\tp\\tp_on1.txt"\n')
		resetfile:write(SoD.TP.BindKey..' nop\n')
		resetfile:write(SoD.TP.ResetKey..' "'..string.sub(t.detailhi,3,string.len(t.detailhi))..t.runcamdist..windowshow..'$$bindloadfilesilent'..t.basepath..'\\tp\\tp_off.txt"\n')
		-- Create tp directory
		cbMakeDirectory(t.basepath..'\\tp')
		-- Create tp_off file
		local tp_off = cbOpen(t.basepath..'\\tp\\tp_off.txt',"w")
		tp_off:write(SoD.TP.ComboKey..' "+ $$'..normalTPPower..t.detaillo..t.flycamdist..windowhide..'$$bindloadfilesilent'..t.basepath..'\\tp\\tp_on1.txt"\n')
		tp_off:write(SoD.TP.BindKey..' nop\n')
		tp_off:close()
		local tp_on1 = cbOpen(t.basepath..'\\tp\\tp_on1.txt',"w")
		tp_on1:write(SoD.TP.ComboKey..' "- $$powexecunqueue'..t.detailhi..t.runcamdist..windowshow..'$$bindloadfilesilent'..t.basepath..'\\tp\\tp_off.txt"\n')
		tp_on1:write(SoD.TP.BindKey..' "+ $$bindloadfilesilent'..t.basepath..'\\tp\\tp_on2.txt"\n')
		tp_on1:close()
		local tp_on2 = cbOpen(t.basepath..'\\tp\\tp_on2.txt',"w")
		tp_on2:write(SoD.TP.BindKey..' "- $$'..normalTPPower..'$$bindloadfilesilent'..t.basepath..'\\tp\\tp_on1.txt"\n')
		tp_on2:close()
	end
	if SoD.TTP and SoD.TTP.Enable and not (profile.Archetype == "Peacebringer") then
		resetfile:write(SoD.TTP.ComboKey..' "+ $$'..teamTPPower..t.detaillo..t.flycamdist..windowhide..'$$bindloadfilesilent'..t.basepath..'\\ttp\\ttp_on1.txt"\n')
		resetfile:write(SoD.TTP.BindKey..' nop\n')
		resetfile:write(SoD.TTP.ResetKey..' "'..string.sub(t.detailhi,3,string.len(t.detailhi))..t.runcamdist..windowshow..'$$bindloadfilesilent'..t.basepath..'\\ttp\\ttp_off.txt"\n')
		-- Create tp directory
		cbMakeDirectory(t.basepath..'\\ttp')
		-- Create tp_off file
		local ttp_off = cbOpen(t.basepath..'\\ttp\\ttp_off.txt',"w")
		ttp_off:write(SoD.TTP.ComboKey..' "+ $$'..teamTPPower..t.detaillo..t.flycamdist..windowhide..'$$bindloadfilesilent'..t.basepath..'\\ttp\\ttp_on1.txt"\n')
		ttp_off:write(SoD.TTP.BindKey..' nop\n')
		ttp_off:close()
		local ttp_on1 = cbOpen(t.basepath..'\\ttp\\ttp_on1.txt',"w")
		ttp_on1:write(SoD.TTP.ComboKey..' "- $$powexecunqueue'..t.detailhi..t.runcamdist..windowshow..'$$bindloadfilesilent'..t.basepath..'\\ttp\\ttp_off.txt"\n')
		ttp_on1:write(SoD.TTP.BindKey..' "+ $$bindloadfilesilent'..t.basepath..'\\ttp\\ttp_on2.txt"\n')
		ttp_on1:close()
		local ttp_on2 = cbOpen(t.basepath..'\\ttp\\ttp_on2.txt',"w")
		ttp_on2:write(SoD.TTP.BindKey..' "- $$'..teamTPPower..'$$bindloadfilesilent'..t.basepath..'\\ttp\\ttp_on1.txt"\n')
		ttp_on2:close()
	end
	
	cbAddReset("up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0$$tell $name, Normal Movement Reset")
	
	resetfile:write(SoD.ToggleKey..' "'.."tell $name, Changing to SoD RUN Mode".."$$up 0$$down 0$$forward 0$$backward 0$$left 0$$right 0".."$$bind_load_file_silent "..t.path.."000000.txt"..'"\n')
end

function module.bindisused(profile)
	if profile.SoD == nil then return nil end
	return profile.SoD.enable
end

cbAddModule(module,"Speed on Demand","Movement")
